* If you are storing identification numbers, rounding could matter. 
* If the identification numbers are integers and take 9 digits or less, 
* store them as longs; otherwise, store them as doubles. 
* doubles have 16 digits of accuracy.

version 7
clear
set matsize 180
set logtype text
set mem 900m
set more off

cd "$root"

capture log close
log using "brazempl/logs/repl-pia-data.log", replace

*YR foreach yr in 90 92 93 94 95 96 97 98 {
foreach yr in 90 97 {

disp 
disp in green "Year: " in yellow "19`yr'"
disp 

tempfile list`yr'
use "brazdspl/pia/random-3firm-firmlist-rndmnr", clear
keep cellid currno firm year
keep if year==19`yr'
sort firm
rename firm firmid
compress
save `list`yr''

tempfile cells`yr'
local sec 4
use "brazempl/est/v1/firmpred-edu-sec`sec'-`yr'", clear
foreach sec in 1 2 5 {
  append using "brazempl/est/v1/firmpred-edu-sec`sec'-`yr'"
  }
label var xbfirm "Avg. Predicted Wage (in plant & firm)"
label var avgpsihat "Avg. Establishment Effect (in firm)"
sort firmid
merge firmid using "brazempl/data/firm-skills-`yr'", nokeep
label var labf_skil_tot "Share Engin'rs, Tech's, Managers"
drop _m labf_wh_tot ln_empl
sort firmid
merge firmid using `list`yr''
capture label drop piarais
label define piarais 1 "RAIS SP establishments but no PIA firm" 2 "PIA firms but no RAIS SP establishment" 3 "RAIS SP establishments in PIA firm"
label values _merge piarais
tab _m
keep if _m==3
keep firmid cellid currno xbfirm avgpsihat avgxbhat labf_skil_tot
order firmid cellid currno xbfirm avgpsihat avgxbhat labf_skil_tot
local i 0
foreach var in xbfirm avgpsihat avgxbhat labf_skil_tot {
    local i = `i' + 1
    local lbl`i' : variable label `var' 
    }
collapse (count) mrgfrms_obs=firm (mean) xbfirm avgpsihat avgxbhat labf_skil_tot, by(cellid currno)
local i 0
foreach var in xbfirm avgpsihat avgxbhat labf_skil_tot {
    local i = `i' + 1
    label var `var' "`lbl`i'' [mean]"
    }
sort currno cellid
compress
save `cells`yr''

use "brazdspl/pia/random-3firm-rndmnr", clear
keep if year==19`yr'
keep cellid currno niv50 frms_obs lnvaladd sales labfbl labfwh profit apimmo1x lnoutput lnapk1 lnapq1 lnlabfbl lnlabfwh lnintmed kappa1 mu
gen ln_empl = ln(labfbl + labfwh)
gen labf_wh_tot  = labfwh/(labfbl + labfwh)
label var labf_wh_tot "Share White Collar Workers"
label var ln_empl "Log Employment"
drop labfbl labfwh
gen ln_cap = ln(apimmo1x)
label var ln_cap "Log Capital"
gen lnsales = ln(sales)
drop sales
gen ln_valadd_empl = lnvaladd - ln_empl
drop lnvaladd
label var ln_valadd_empl "Log of Value Added / Labor Force"
gen ln_sales_empl = lnsales - ln_empl
drop lnsales
label var ln_sales_empl "Log of Sales / Labor Force"
gen profit_cap = profit / apimmo1x
drop profit apimmo1x
label var profit_cap "Operating Income / Capital"
gen ln_cap_empl = ln_cap - ln_empl
label var ln_cap_empl "Log of Capital / Labor Force"
order cellid currno niv50 ln_empl ln_cap ln_valadd_empl ln_sales_empl ln_cap_empl profit_cap labf_wh_tot frms_obs
label var niv50 "Sector (Nivel 50)"
sort currno cellid
merge currno cellid using `cells`yr''
capture label drop piacells
label define piacells 1 "RAIS&PIA firms but no cell match" 2 "Firms in cells but no RAIS&PIA match" 3 "Firms in cells matched with RAIS&PIA"
label values _merge piacells
tab _m
drop _m
order cellid currno niv50 xbfirm avgpsihat avgxbhat ln_empl ln_cap ln_valadd_empl ln_sales_empl ln_cap_empl profit_cap labf_wh_tot labf_skil_tot frms_obs

drop if mrgfrms_obs==. | frms_obs==.
qui do "brazaux/auxil/niv50.do"
label values niv50 niv50
compress

* Productivity estimates (as in brazprod/%stata/%4tfp/prodlevel.do)
local esttype "op" /* "op" : Olley-Pakes */
local choice 3 /* Choice 3: FGV-IPA (and general) Deflators 86-98 */
if `choice'==3 {local ext "ipa"}
local fdfl 2 /* Choice 2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
global out 2 /* Choice 2: "output" */
if $out==2 {local outtype "output"}
global trd 0 /* Choice 0: trend variables and year dummies OFF */
if $trd==0 {local trdtype "notrend"}
global fe 1 /* Choice 1: fixed effects in OP estimation ON  */
if $fe {local fetype "fe"}
global iniols 2 /* Choice 2: Set initial values to FE estimates and terms from linear regression */
global polynl 3 /* Choice 3: Polynomial of 3rd order is used in Step 3 */
local polynl=$polynl
global xeff 1 /* Choice 1: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}
sort niv50
merge niv50 using "brazdspl/pia/prodcoeff-brazprod", nokeep
tab _m
if "`esttype'" == "op" {
  if $fe~=2 {
   if $out==2 {
    if $trd==3 {gen lntfp = lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed - bklegri*kletgril}
    else       {gen lntfp = lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed}
    }
  }
}
label var lntfp "Log TFP"
if "`esttype'" == "op" {
    if $out==2 {gen double lnlp=lntfp + betak*lnapk1 + betaq*lnapq1 - (1-betabl-betawh)*log((exp(lnlabfwh)+exp(lnlabfbl))) + betaintm*lnintmed}
  }
label var lnlp "Log LP"
if "`esttype'" == "op"  { gen double bgkap = betakappa * kappa1 }
label var bgkap "betak * gk * kappa"
if "`esttype'" == "op"  { gen double bgmu = betamu * mu }
label var bgmu "betam * gm * mu"
drop bsecfe50 beta* ols* wi* _merge lnoutput lnapk1 lnapq1 lnlabfbl lnlabfwh lnintmed bgkap bgmu
rename kappa1 kappa

label var niv50 "Sector (Nivel 50)"
label var xbfirm "Avg Pred Wage (plant) [mean]"
label var avgpsihat "Avg Estm't Effect (firm) [mean]"
label var avgxbhat "Avg Pred Wage (firm) [mean]"
label var ln_empl "Log Employees"
label var ln_cap "Log Capital"
label var ln_valadd_empl "Log of Value Added / Labor Force"
label var ln_sales_empl "Log of Sales / Labor Force"
label var ln_cap_empl "Log of Capital / Labor Force"
label var profit_cap "Operating Income / Capital"
label var labf_wh_tot "Share White Collar Workers"
label var labf_skil_tot "Sh. Eng's/Tech's/Manag's [mean]"
label var lntfp "Log TFP"
label var lnlp "Log LP"
label var kappa "Foreign Machinery Share"
label var mu "Foreign Intermediates Share"
label var frms_obs "(count) firm"
label var mrgfrms_obs "(count) firmid"

egen firmgrp = group(cellid currno)
label var firmgrp "Firm group ID (cellid contyrs)"
drop cellid currno
order firmgrp niv50 xbfirm avgpsihat avgxbhat ln_empl ln_cap ln_valadd_empl ln_sales_empl ln_cap_empl profit_cap labf_wh_tot labf_skil_tot lntfp lnlp kappa mu frms_obs mrgfrms_obs
compress
sort firmgrp
save "brazempl/use-firms-`yr'", replace

}

log close
cd "$home"
