version 8
clear
set matsize 180
set logtype text
set mem 800m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture program drop summtex
program define summtex
    syntax [varlist] [, Path(string) PREcision(real 0) DIGits(integer 3) Name(string) ]
    local nvar : word count `varlist'
    local rownum = `nvar' + 1
    matrix `name'_tbl = J(`rownum',2,-999)
    matname `name'_tbl mean sd, columns(1..2) explicit
    local i 0
    foreach var of local varlist {
      local i = `i' + 1
      qui summ `var'
      if `r(N)'~=0 {
        matrix `name'_tbl[`i',1] = `r(mean)'
        matrix `name'_tbl[`i',2] = `r(sd)'
        }
      else {
        matrix `name'_tbl[`i',1] = -999
        matrix `name'_tbl[`i',2] = -999
        }
      matname `name'_tbl `var', rows(`i') explicit
      }
    qui count
    matrix `name'_tbl[`rownum',1] = `r(N)'
    matname `name'_tbl r(N), rows(`rownum') explicit
    est2tex `name', replace dropall preserve precision(`precision') digits(`digits') ready path(`path')
end

capture program drop tabl2tex
program define tabl2tex
    * NOTE: TOTALS ARE STILL UNWEIGHTED, NO PROPER AVERAGES ARE PRODUCED
    * USE SUMM FUNCTION IN FUTURE TO CALCULATE MARGINALS
    version 8
    syntax [varlist] [if] [in] [pweight fweight] [, Type(string) Rowvar(varname) Colvar(varname) ROWLabel(string) COLLabel(string) Path(string) Name(string) NOTOTal FANCY REPLACE]
    args var
    local var = trim(subinstr("`var'",`","',"",.))
    if "`type'"=="sum" & "`nototal'"=="" {
        local totopt = "row col"
        }
    if "`weight'"~="" {
        local wghtopt = "[`weight'`exp']"
        }
    * disp "`var': table `rowvar' `colvar' `if' `in' `wghtopt', c(`type' `var') `totopt'"
    * disp "`var': collapse (`type') `var' `if' `in' `wghtopt', by(`rowvar' `colvar') fast"
    confirm numeric variable `rowvar' `colvar'
    foreach colrow in col row {
      if "``colrow'label'" == "" {
        local `colrow'label : value label ``colrow'var'
        if "``colrow'label'" == "" {
            tempname lblnam
            qui count
            forvalues i = 1/`r(N)' {
                local lbltit = ``colrow'var'[`i']
                label define `lblnam' `lbltit' "`lbltit'", modify
                }
             local `colrow'label = "`lblnam'"
             }
           }
      label values ``colrow'var' ``colrow'label'
      }
    table `rowvar' `colvar' `if' `in' `wghtopt', c(`type' `var') `totopt'
    tempfile collblf
    qui label save `collabel' using `collblf'.do
    collapse (`type') `var' `if' `in' `wghtopt', by(`rowvar' `colvar') fast
    rename `var' `var'_
    qui reshape wide `var'_, i(`rowvar') j(`colvar')
    qui duplicates drop
    rename `rowvar' _rowname
    if "`totopt'" ~= "" {
      egen _total = r`type'(`var'_*)
      qui count
      local newobs = `r(N)' + 1
      qui set obs `newobs'
      qui summ _rowname
      local totlno = -999
      qui replace _rowname = `totlno' in `newobs'
      label define `rowlabel' `totlno' "_total", modify
      foreach jvar of varlist `var'_* _total {
        qui summ `jvar', meanonly
        if `r(N)' > 0 {
            qui replace `jvar' = `r(`type')' in `newobs'
            }
        }
      }
    qui do `collblf'.do
    foreach jvar of varlist `var'_* {
        local cntr = substr("`jvar'",-index(reverse("`jvar'"),"_")+1,length("`jvar'")-index(reverse("`jvar'"),"_"))
        * disp "`cntr'"
        local jvarnam : label `collabel' `cntr'
        * disp "`jvarnam'"
        capture rename `jvar' `jvarnam'
        }
    decode _rowname, gen(`rowvar')
    drop _rowname
    rename `rowvar' _rowname
    order _rowname
    qui replace _rowname = substr(_rowname,1,20)
    qui replace _rowname = subinstr(_rowname," ","_",.)
    qui replace _rowname = subinstr(_rowname,";","_",.)
    qui replace _rowname = subinstr(_rowname,",","_",.)
    qui replace _rowname = subinstr(_rowname,".","_",.)
    qui replace _rowname = subinstr(_rowname,":","_",.)
    qui replace _rowname = subinstr(_rowname,"!","_",.)
    qui compress
    tempname tmpname
    qui save `path'/`tmpname'_tbl, replace
    qui matload `tmpname'_tbl, p(`path') over dropall
    local erasfile = subinstr("`path'" + "\" + "`tmpname'_tbl.dta","/",`"\"',.)
    erase `erasfile'
    mat rename `tmpname'_tbl `name'_tbl
    est2tex `name', ready `replace' preserve path(`path') `fancy'
end


mat piacnt_tbl = J(2,1,-999)
matname piacnt_tbl r(N_ids) r(N_grps), rows(1..2) explicit
*YR foreach yr in 90 92 93 94 95 96 97 98 {
foreach yr in 90 97 {
  disp 
  disp in green "Year: " in yellow "19`yr'"
  disp 
  mat _pia`yr' = J(2,1,-999)
  matname _pia`yr' pia`yr', columns(1) explicit
  use "brazdspl/pia/random-3firm-firmlist-rndmnr", clear
  keep cellid currno firm year indsp niv50 contyrs
  rename firm firmid
  egen firmgrp = group(indsp niv50 contyrs currno)
  label var firmgrp "Firm group ID (cellid contyrs)"
  order firmgrp firmid year
  keep if year==19`yr'
  sort firmgrp firmid
  qui count
  mat _pia`yr'[1,1] = `r(N)'
  keep firmgrp
  sort firmgrp
  qui duplicates drop
  qui count
  mat _pia`yr'[2,1] = `r(N)'
  mat piacnt_tbl = piacnt_tbl , _pia`yr'
  mat drop _pia`yr'
}
local cols = colsof(piacnt_tbl)
mat piacnt_tbl = piacnt_tbl[1..2,2..`cols']
drop _all
est2tex piacnt, replace ready path(brazempl/tex/v1/summ) fancy


*YR foreach yr in 90 92 93 94 95 96 97 98 {
foreach yr in 90 97 {
  disp 
  disp in green "Year: " in yellow "19`yr'"
  disp 
  use "brazempl/use-firms-`yr'", clear
  gen byte year = `yr'
  label var year "Calendar year"
  keep firmgrp year niv50 avgxbhat avgpsihat ln_sales_empl ln_valadd_empl profit_cap ln_empl ln_cap ln_cap_empl labf_wh_tot labf_skil_tot lntfp lnlp kappa mu
  order firmgrp year niv50
  sort niv50 year
  merge niv50 year using "brazaux/auxil/seclvl", nokeep
  drop _m
  label var realexch "Real.Exch.Rate: E*USD/P"
  label var fdistk "FDI Stock (Billion USD)"
  drop year
  keep herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl ln_valadd_empl profit_cap lntfp avgxbhat avgpsihat 
  order herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl ln_valadd_empl profit_cap lntfp avgxbhat avgpsihat 
  summtex *, path(brazempl/tex/v1/summ) digits(4) name(summtex`yr'pia)
}

foreach yr in 90 97 {
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sectors: " in yellow "all"
    disp
    use "brazempl/use-brazempl-`yr'", clear
    keep lnwage indfem indprof indtech indwhit indsklb indprim indhigh indscoll indgrad sector
    gen byte indnoskl = (indprof==0 & indtech==0 & indwhit==0 & indsklb==0)
    label var indnoskl "Less Than Primary Education"
    gen byte indblue = (indprof==0 & indtech==0 & indwhit==0)
    label var indblue "Blue-collar occupation"
    gen byte indnocoll = (indprim==1 | indhigh==1)
    label var indnocoll "Less than college education"
    keep lnwage sector indfem indblue indnocoll
    order lnwage sector indfem indblue indnocoll
    preserve
    foreach var in indfem indblue indnocoll {
      restore, preserve
      tabl2tex lnwage, type(mean) r(`var') c(sector) p(brazempl/tex/v1/summ) name(lnwmean`yr'`var') fancy replace
      restore, preserve
      tabl2tex lnwage, type(count) r(`var') c(sector) p(brazempl/tex/v1/summ) name(count`yr'`var') fancy replace
      restore, preserve
      tabl2tex lnwage, type(sd) r(`var') c(sector) p(brazempl/tex/v1/summ) name(sdv`yr'`var') fancy replace
      }
    restore
  }


*YR forvalues yr = 90/98 {
foreach yr in 90 97 {
  foreach sec in 1 2 4 5 {
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sector: " in yellow "`sec'"
    disp
    use "brazempl/use-brazempl-`yr'", clear
    keep if sector==`sec'
    gen byte indnoskl = (indprof==0 & indtech==0 & indwhit==0 & indsklb==0)
    label var indnoskl "Less Than Primary Education"
    order lnwage potexper potxper2 potxper3 potxper4 tenuryr tenr2 tenr3 tenr4 indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indnoskl indfem
    keep  lnwage potexper potxper2 potxper3 potxper4 tenuryr tenr2 tenr3 tenr4 indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indnoskl indfem
    foreach var in lnwage tenuryr tenr2 tenr3 tenr4 potexper potxper2 potxper3 potxper4 indprof indtech indwhit indsklb indnoskl indprim indhigh indscoll indgrad {
      local dattyp = ""
      if substr("`var'",1,3)=="ind" {
          local dattyp = "byte"
          }
      gen `dattyp' fem_`var' = indfem * `var'
      local lbl : variable label `var'
      local lbl = subinstr("`lbl'"," (at plant)","",.)
      local lbl = subinstr("`lbl'"," Term","",.)
      local lbl = subinstr("`lbl'"," Occupation","",.)
      local lbl = subinstr("`lbl'"," Education","",.)
      local lbl = "Fem. " + "`lbl'" + " Interact."
      label var fem_`var' "`lbl'"
      }
    compress
    * foreach var in potxper tenr {
    *   forvalues i = 2/4 {
    *     replace `var'`i' = `var'`i' / 1.0e+`i'
    *     local pot = 10^`i'
    *     local lbl : variable label `var'`i'
    *     label var `var'`i' "`lbl' (/`pot')"
    *     replace fem_`var'`i' = fem_`var'`i' / 1.0e+`i'
    *     local lbl : variable label fem_`var'`i'
    *     label var fem_`var'`i' "`lbl' (/`pot')"
    *     }
    *   }
    order lnwage potexper potxper2 potxper3 potxper4 tenuryr tenr2 tenr3 tenr4 indprof indtech indwhit indsklb indnoskl indprim indhigh indscoll indgrad indfem fem_lnwage fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_tenuryr fem_tenr2 fem_tenr3 fem_tenr4 fem_indprof fem_indtech fem_indwhit fem_indsklb fem_indnoskl fem_indprim fem_indhigh fem_indscoll fem_indgrad 
    summtex *, path(brazempl/tex/v1/summ) digits(4) name(summtex`yr'sec`sec')
  }
}

cd "$home"
