/* Only two occupation categories: To return to four categories replace "sklb" with "blue" */

local refyr = 90
local refsec = 4

version 8
set matsize 120
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture program drop dropmiss
program define dropmiss
    syntax [varlist]
    local nvar : word count `varlist'
    foreach var of local varlist {
      capture drop if `var'==.
      }
end

foreach blue in "" "blu" {

/* EDUCATION PROFILES */
/*--------------------*/

local profile "edu"
local sec 4

if "`profile'"=="edu" {
  local proflvar1 "prim"
  local proflvar2 "high"
  local proflvar3 "coll"
  local proflvar4 "grad"
  }


/* Brazil 1990 and 1997 */

/* use regression results w/ education indicators */
foreach infrm in rais informl forml {
foreach yr in 90 97 {
* Education variables
use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
keep _rowname yr`yr'sec`sec'edu`blue'  /* regression results w/ education indicators */
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
drop if _rowname=="_se"
keep if substr(_rowname,-4,4)=="`proflvar1'" | substr(_rowname,-4,4)=="`proflvar2'" | substr(_rowname,-4,4)=="`proflvar3'" | substr(_rowname,-4,4)=="`proflvar4'"
save "brazempl/est/pnad/br`yr'sec`sec'_`profile'_`infrm'in", replace
drop _all
matload br`yr'sec`sec'_`profile'_`infrm'in, path(brazempl/est/pnad) over
erase brazempl\est\pnad\br`yr'sec`sec'_`profile'_`infrm'in.dta
  tempfile fpsihat1
  use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
  keep _rowname yr`yr'sec`sec'edu`blue'
  rename yr`yr'sec`sec'edu`blue' mean
  keep if _rowname=="_cons"
  replace _rowname = "psihat" if _rowname=="_cons"
  save `fpsihat1'
use "brazempl/tex/pnad/corr/corr`infrm'`yr'sec`sec'edu`blue'_tbl", clear
append using `fpsihat1'
keep _rowname mean
keep if _rowname=="xbhat" | _rowname=="psihat"
save "brazempl/est/pnad/br`yr'sec`sec'_mean`profile'_`infrm'out", replace
drop _all
matload br`yr'sec`sec'_mean`profile'_`infrm'out, path(brazempl/est/pnad) over
erase brazempl\est\pnad\br`yr'sec`sec'_mean`profile'_`infrm'out.dta
* Other variables than `profile'_`infrm'
tempfile summtex
if "`infrm'"~="rais" {
  use "brazempl/tex/pnad/summ/summtex`yr'sec`sec'`infrm'_tbl", clear
  }
else {
  use "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl", clear
  gen _blu = mean if substr(_rowname,-4,4)=="sklb" | substr(_rowname,-5,5)=="noskl"
  * gen _fem = mean if _rowname=="indfem"
  qui summ _blu if substr(_rowname,1,4)~="fem_"
  local totblue = `r(N)' * `r(mean)'
  qui summ _blu if substr(_rowname,1,4)=="fem_"
  local femblue = `r(N)' * `r(mean)'
  drop _blu
  expand 2 if substr(_rowname,-5,5)=="noskl"
  replace _rowname = "indblue" if _n==_N-1
  replace _rowname = "fem_indblue" if _n==_N
  replace mean = `totblue' if _rowname == "indblue"
  replace mean = `femblue' if _rowname == "fem_indblue"
  replace sd=-999 if _rowname == "indblue" | _rowname == "fem_indblue"
  }
keep _rowname mean
drop if substr(_rowname,-6,6)=="unsklb"
compress
sort _rowname
save `summtex'
use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
keep _rowname yr`yr'sec`sec'edu`blue'
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
drop if _rowname=="_se"
drop if substr(_rowname,-4,4)=="`proflvar1'" | substr(_rowname,-4,4)=="`proflvar2'" | substr(_rowname,-4,4)=="`proflvar3'" | substr(_rowname,-4,4)=="`proflvar4'"
* drop if yr`yr'sec`sec'edu`blue' == -999 | substr(_rowname,1,2)=="e(" }
/* following line depends on use of education regression results */
keep if substr(_rowname,-5,5) == "exper" | substr(_rowname,-5,5) == "xper2" | substr(_rowname,-5,5) == "xper3" | substr(_rowname,-5,5) == "xper4" | substr(_rowname,-4,4) == "prof" | substr(_rowname,-4,4) == "tech" | substr(_rowname,-4,4)=="whit" | substr(_rowname,-4,4)=="sklb" | substr(_rowname,-4,4)=="prim" | substr(_rowname,-4,4)=="high" | substr(_rowname,-4,4)=="coll" | substr(_rowname,-4,4)=="grad" | substr(_rowname,-4,4)=="dfem" | substr(_rowname,-4,4)=="cons" | substr(_rowname,-4,4)=="blue"
gen _count = _n
sort _rowname
merge _rowname using "`summtex'", nokeep
drop _m
sort _count
drop _count
save "brazempl/est/pnad/mmr`yr'sec`sec'`profile'_`infrm'", replace
drop _all
matload mmr`yr'sec`sec'`profile'_`infrm', path(brazempl/est/pnad) over
erase brazempl\est\pnad\mmr`yr'sec`sec'`profile'_`infrm'.dta
local rownum = rowsof(mmr`yr'sec`sec'`profile'_`infrm')
forvalues i = 1/`rownum' {
 forvalues j = 1/2 {
  if mmr`yr'sec`sec'`profile'_`infrm'[`i',`j'] == -999 {
    mat mmr`yr'sec`sec'`profile'_`infrm'[`i',`j'] = 0
    }
   }
  }
* Multiply point estimate by sample mean (multiplication by mean zero when point estimate missing)
mat _xbbrmasc`yr'sec`sec' = mmr`yr'sec`sec'`profile'_`infrm'[1..9,1] '  * mmr`yr'sec`sec'`profile'_`infrm'[1..9,2]
mat _xbbrfemi`yr'sec`sec' = mmr`yr'sec`sec'`profile'_`infrm'[1..19,1] ' * mmr`yr'sec`sec'`profile'_`infrm'[1..19,2]
mat drop mmr`yr'sec`sec'`profile'_`infrm'
}

local rownames "indprim indhigh indscoll indgrad fem_indprim fem_indhigh fem_indscoll fem_indgrad xbhatmasc xbhatfemi psihat"
mat _brcomp`sec' = br90sec`sec'_`profile'_`infrm'in , br97sec`sec'_`profile'_`infrm'in
mat drop br90sec`sec'_`profile'_`infrm'in br97sec`sec'_`profile'_`infrm'in
mat _xbbrmasc`sec' = _xbbrmasc90sec`sec' , _xbbrmasc97sec`sec'
mat _xbbrfemi`sec' = _xbbrfemi90sec`sec' , _xbbrfemi97sec`sec'
mat drop _xbbrmasc90sec`sec' _xbbrmasc97sec`sec' _xbbrfemi90sec`sec' _xbbrfemi97sec`sec'
mat _brpsihat`sec' = br90sec`sec'_mean`profile'_`infrm'out[2,1] , br97sec`sec'_mean`profile'_`infrm'out[2,1]
mat drop br90sec`sec'_mean`profile'_`infrm'out br97sec`sec'_mean`profile'_`infrm'out
mat _brcomp`sec' = _brcomp`sec' \ _xbbrmasc`sec'
mat _brcomp`sec' = _brcomp`sec' \ _xbbrfemi`sec'
mat _brcomp`sec' = _brcomp`sec' \ _brpsihat`sec'
mat drop _xbbrmasc`sec' _xbbrfemi`sec' _brpsihat`sec'
matname _brcomp`sec' `rownames', rows(1..11) explicit
mat braz`profile'_`infrm'in_tbl = _brcomp4

local imax = rowsof(braz`profile'_`infrm'in_tbl)
local jmax = colsof(braz`profile'_`infrm'in_tbl)
forvalues i = 1/`imax' {
 forvalues j = 1/`jmax' {
   if braz`profile'_`infrm'in_tbl[`i',`j']==. {
      mat braz`profile'_`infrm'in_tbl[`i',`j']=-999
     }
   }
  }

} /* Close `infrm' loop */


/* EDUCATION tabulations: Sectors within Brazil */

foreach infrm in rais informl forml {
mat _seeddta = (1)
drop _all
svmat _seeddta
mat drop _seeddta
rename _seeddta1 _rowname
local j = 0
foreach var in br90sec4 br97sec4 {
  local j = `j' + 1
  local k = 0
  foreach edulvl in prim high scoll grad {
    local k = `k' + 1    
    local kfem = `k' + 4
    gen `var'_`edulvl'_0 = exp( brazedu_`infrm'in_tbl[`k',`j'] * _rowname + brazedu_`infrm'in_tbl[9,`j'] + brazedu_`infrm'in_tbl[11,`j'] ) 
    gen `var'_`edulvl'_1 = exp( ln(`var'_`edulvl'_0) + brazedu_`infrm'in_tbl[`kfem',`j'] * _rowname + brazedu_`infrm'in_tbl[10,`j'] )
    replace `var'_`edulvl'_0 = `var'_`edulvl'_0 / exp( brazedu_`infrm'in_tbl[9,`j'] + brazedu_`infrm'in_tbl[11,`j'] )
    replace `var'_`edulvl'_1 = `var'_`edulvl'_1 / exp( brazedu_`infrm'in_tbl[9,`j'] + brazedu_`infrm'in_tbl[10,`j'] + brazedu_`infrm'in_tbl[11,`j'] )
    }
  }
foreach edulvl in prim high scoll grad {
 foreach gender in 0 1 {
  foreach yr in 90 97 {
    label var br`yr'sec4_`edulvl'_`gender' "Manufacturing 19`yr'"
    }
   }
  }
reshape long br90sec4_ br97sec4_ , i(_rowname) j(edu`blue'_gender) string
replace edu`blue'_gender = subinstr(edu`blue'_gender,"_0",":masc",.)
replace edu`blue'_gender = subinstr(edu`blue'_gender,"_1",":fem",.)
drop _rowname
rename edu`blue'_gender _rowname
foreach var in br90sec4 br97sec4 {
  rename `var'_ `var'
  }
foreach yr in 90 97 {
  label var br`yr'sec4 "Manufacturing 19`yr'"
  }
gen byte gender = ( substr(_rowname,-4,4) == ":fem" )
gen byte hier = 1 if substr(_rowname,1,4) == "grad"
replace  hier = 2 if substr(_rowname,1,4) == "scol"
replace  hier = 3 if substr(_rowname,1,4) == "high"
replace  hier = 4 if substr(_rowname,1,4) == "prim"
sort gender hier
drop hier gender
drop if substr(_rowname,1,4) == "grad"
save "brazempl/tex/pnad/tables/prflbrsecedu`blue'_`infrm'_tbl", replace
matload prflbrsecedu`blue'_`infrm'_tbl, p(brazempl/tex/pnad/tables) over dropall
est2tex prflbrsecedu`blue'_`infrm', replace dropall preserve ready path(brazempl/tex/pnad/tables) fancy
} /* Close `infrm' loop */



/* GENDER PROFILES */
/*----------------*/

local profile "sex"

/* Brazil 1990 and 1997 */

* matload cntfemtot, path(rais-sp/rais) over dropall
* matload cntmasctot, path(rais-sp/rais) over dropall

/* use regression results w/ education indicators */
foreach infrm in rais informl forml {
foreach yr in 90 97 {
foreach sec in 4 {
* Education variables
use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
keep _rowname yr`yr'sec`sec'edu`blue'  /* regression results w/ education indicators */
drop if _rowname=="_se"
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
keep if substr(_rowname,1,4)=="fem_" | _rowname=="indfem"
save "brazempl/est/pnad/br`yr'sec`sec'_`profile'_`infrm'femi", replace
drop _all
matload br`yr'sec`sec'_`profile'_`infrm'femi, path(brazempl/est/pnad) over
erase brazempl\est\pnad\br`yr'sec`sec'_`profile'_`infrm'femi.dta
  tempfile fpsihat2
  use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
  keep _rowname yr`yr'sec`sec'edu`blue'
  rename yr`yr'sec`sec'edu`blue' mean
  keep if _rowname=="_cons"
  replace _rowname = "psihat" if _rowname=="_cons"
  save `fpsihat2'
use "brazempl/tex/pnad/corr/corr`infrm'`yr'sec`sec'edu`blue'_tbl", clear
append using `fpsihat2'
keep _rowname mean
keep if _rowname=="xbhat" | _rowname=="psihat"
save "brazempl/est/pnad/br`yr'sec`sec'_mean`profile'_`infrm'masc", replace
drop _all
matload br`yr'sec`sec'_mean`profile'_`infrm'masc, path(brazempl/est/pnad) over
erase brazempl\est\pnad\br`yr'sec`sec'_mean`profile'_`infrm'masc.dta
* Other variables than `profile'_`infrm'
tempfile summtex
if "`infrm'"~="rais" {
  use "brazempl/tex/pnad/summ/summtex`yr'sec`sec'`infrm'_tbl", clear
  }
else {
  use "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl", clear
  gen _blu = mean if substr(_rowname,-4,4)=="sklb" | substr(_rowname,-5,5)=="noskl"
  * gen _fem = mean if _rowname=="indfem"
  qui summ _blu if substr(_rowname,1,4)~="fem_"
  local totblue = `r(N)' * `r(mean)'
  qui summ _blu if substr(_rowname,1,4)=="fem_"
  local femblue = `r(N)' * `r(mean)'
  drop _blu
  expand 2 if substr(_rowname,-5,5)=="noskl"
  replace _rowname = "indblue" if _n==_N-1
  replace _rowname = "fem_indblue" if _n==_N
  replace mean = `totblue' if _rowname == "indblue"
  replace mean = `femblue' if _rowname == "fem_indblue"
  replace sd=-999 if _rowname == "indblue" | _rowname == "fem_indblue"
  }
keep _rowname mean
compress
sort _rowname
save `summtex'
use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
keep _rowname yr`yr'sec`sec'edu`blue'
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
drop if _rowname=="_se"
* drop if yr`yr'sec`sec'edu`blue' == -999 | substr(_rowname,1,2)=="e("
/* following line depends on use of education regression results */
keep if substr(_rowname,-5,5) == "exper" | substr(_rowname,-5,5) == "xper2" | substr(_rowname,-5,5) == "xper3" | substr(_rowname,-5,5) == "xper4" | substr(_rowname,-4,4) == "prof" | substr(_rowname,-4,4) == "tech" | substr(_rowname,-4,4)=="whit" | substr(_rowname,-4,4)=="sklb" | substr(_rowname,-4,4)=="prim" | substr(_rowname,-4,4)=="high" | substr(_rowname,-4,4)=="coll" | substr(_rowname,-4,4)=="grad" | substr(_rowname,-4,4)=="dfem" | substr(_rowname,-4,4)=="cons" | substr(_rowname,-4,4)=="blue"
gen _count = _n
sort _rowname
merge _rowname using "`summtex'", nokeep
drop _m
sort _count
drop _count
save "brazempl/est/pnad/mmr`yr'sec`sec'`profile'_`infrm'", replace
drop _all
matload mmr`yr'sec`sec'`profile'_`infrm', path(brazempl/est/pnad) over
erase brazempl\est\pnad\mmr`yr'sec`sec'`profile'_`infrm'.dta
local rownum = rowsof(mmr`yr'sec`sec'`profile'_`infrm')
forvalues i = 1/`rownum' {
 forvalues j = 1/2 {
  if mmr`yr'sec`sec'`profile'_`infrm'[`i',`j'] == -999 {
    mat mmr`yr'sec`sec'`profile'_`infrm'[`i',`j'] = 0
    }
   }
  }
* Multiply point estimate by sample mean (multiplication by mean zero when point estimate missing)
mat _xbbrmasc`yr'sec`sec' = mmr`yr'sec`sec'`profile'_`infrm'[1..13,1] '  * mmr`yr'sec`sec'`profile'_`infrm'[1..13,2]
mat _xbbrfemi`yr'sec`sec' = mmr`yr'sec`sec'`profile'_`infrm'[14..27,1] ' * mmr`yr'sec`sec'`profile'_`infrm'[14..27,2]
mat drop mmr`yr'sec`sec'`profile'_`infrm'
}
}
local rownames "xbhatmasc xbhatfemi psihat"
foreach sec in 4 {
mat _brcomp`sec' = br90sec`sec'_`profile'_`infrm'femi , br97sec`sec'_`profile'_`infrm'femi
local colnames : colfullnames _brcomp`sec'
mat drop _brcomp`sec'
mat drop br90sec`sec'_`profile'_`infrm'femi br97sec`sec'_`profile'_`infrm'femi
mat _xbbrmasc`sec' = _xbbrmasc90sec`sec' , _xbbrmasc97sec`sec'
mat _xbbrfemi`sec' = _xbbrfemi90sec`sec' , _xbbrfemi97sec`sec'
mat drop _xbbrmasc90sec`sec' _xbbrmasc97sec`sec' _xbbrfemi90sec`sec' _xbbrfemi97sec`sec'
mat _brpsihat`sec' = br90sec`sec'_mean`profile'_`infrm'masc[2,1] , br97sec`sec'_mean`profile'_`infrm'masc[2,1]
mat drop br90sec`sec'_mean`profile'_`infrm'masc br97sec`sec'_mean`profile'_`infrm'masc
mat _brcomp`sec' = _xbbrmasc`sec' \ _xbbrfemi`sec' \ _brpsihat`sec'
mat drop _xbbrmasc`sec' _xbbrfemi`sec' _brpsihat`sec'
matname _brcomp`sec' `rownames', rows(1..3) explicit
matname _brcomp`sec' `colnames', columns(1..2) explicit
}

local sec 4
mat braz`profile'_`infrm'femi_tbl = _brcomp4

} /* Close `infrm' loop */


/* GENDER tabulations: Sectors within Brazil */

foreach infrm in rais informl forml {
mat _seeddta = (1)
drop _all
svmat _seeddta
mat drop _seeddta
rename _seeddta1 _rowname
local j = 0
foreach var in br90sec4 br97sec4 {
  local j = `j' + 1
  gen `var'_masc = exp( brazsex_`infrm'femi_tbl[1,`j'] * _rowname + brazsex_`infrm'femi_tbl[3,`j'] ) 
  gen `var'_femi = exp( ln(`var'_masc) + brazsex_`infrm'femi_tbl[2,`j'] * _rowname )
  replace `var'_femi = `var'_femi / `var'_masc
  replace `var'_masc = 1
  }
foreach gender in masc femi {
  foreach yr in 90 97 {
    label var br`yr'sec4_`gender' "Manufacturing 19`yr'"
    }
  }
reshape long br90sec4_ br97sec4_, i(_rowname) j(gender) string
drop _rowname
rename gender _rowname
foreach var in br90sec4 br97sec4 {
  rename `var'_ `var'
  }
foreach yr in 90 97 {
  label var br`yr'sec4 "Manufacturing 19`yr'"
  }
sort _rowname
compress
save "brazempl/tex/pnad/tables/prflbrsecsex`blue'_`infrm'_tbl", replace
matload prflbrsecsex`blue'_`infrm'_tbl, p(brazempl/tex/pnad/tables) over dropall
est2tex prflbrsecsex`blue'_`infrm', replace dropall preserve ready path(brazempl/tex/pnad/tables) fancy
} /* Close `infrm' loop */

} /* Close `blue' loop */


/* BLUE-WHITE COLLAR PROFILES */
/*----------------------------*/

local profile "occblu"

/* Brazil 1990 and 1997 */

* matload cntfemtot, path(rais-sp/rais) over dropall
* matload cntmasctot, path(rais-sp/rais) over dropall

/* use regression results w/ education indicators */
foreach infrm in rais informl forml {
foreach yr in 90 97 {
foreach sec in 4 {
* Education variables
use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
keep _rowname yr`yr'sec`sec'edublu  /* regression results w/ education indicators */
drop if _rowname=="_se"
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
keep if substr(_rowname,-7,7)=="indblue"
save "brazempl/est/pnad/br`yr'sec`sec'_`profile'_`infrm'in", replace
drop _all
matload br`yr'sec`sec'_`profile'_`infrm'in, path(brazempl/est/pnad) over
erase brazempl\est\pnad\br`yr'sec`sec'_`profile'_`infrm'in.dta
  tempfile fpsihat2
  use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
  keep _rowname yr`yr'sec`sec'edublu
  rename yr`yr'sec`sec'edublu mean
  keep if _rowname=="_cons"
  replace _rowname = "psihat" if _rowname=="_cons"
  save `fpsihat2'
use "brazempl/tex/pnad/corr/corr`infrm'`yr'sec`sec'edublu_tbl", clear
append using `fpsihat2'
keep _rowname mean
keep if _rowname=="xbhat" | _rowname=="psihat"
save "brazempl/est/pnad/br`yr'sec`sec'_mean`profile'_`infrm'out", replace
drop _all
matload br`yr'sec`sec'_mean`profile'_`infrm'out, path(brazempl/est/pnad) over
erase brazempl\est\pnad\br`yr'sec`sec'_mean`profile'_`infrm'out.dta
* Other variables than `profile'_`infrm'
tempfile summtex
if "`infrm'"~="rais" {
  use "brazempl/tex/pnad/summ/summtex`yr'sec`sec'`infrm'_tbl", clear
  }
else {
  use "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl", clear
  gen _blu = mean if substr(_rowname,-4,4)=="sklb" | substr(_rowname,-5,5)=="noskl"
  * gen _fem = mean if _rowname=="indfem"
  qui summ _blu if substr(_rowname,1,4)~="fem_"
  local totblue = `r(N)' * `r(mean)'
  qui summ _blu if substr(_rowname,1,4)=="fem_"
  local femblue = `r(N)' * `r(mean)'
  drop _blu
  expand 2 if substr(_rowname,-5,5)=="noskl"
  replace _rowname = "indblue" if _n==_N-1
  replace _rowname = "fem_indblue" if _n==_N
  replace mean = `totblue' if _rowname == "indblue"
  replace mean = `femblue' if _rowname == "fem_indblue"
  replace sd=-999 if _rowname == "indblue" | _rowname == "fem_indblue"
  }
keep _rowname mean
compress
sort _rowname
save `summtex'
use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
keep _rowname yr`yr'sec`sec'edublu
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
drop if _rowname=="_se"
drop if substr(_rowname,-7,7)=="indblue"
* drop if yr`yr'sec`sec'edublu == -999 | substr(_rowname,1,2)=="e("
/* following line depends on use of education regression results */
keep if substr(_rowname,-5,5) == "exper" | substr(_rowname,-5,5) == "xper2" | substr(_rowname,-5,5) == "xper3" | substr(_rowname,-5,5) == "xper4" | substr(_rowname,-4,4) == "prof" | substr(_rowname,-4,4) == "tech" | substr(_rowname,-4,4)=="whit" | substr(_rowname,-4,4)=="sklb" | substr(_rowname,-4,4)=="prim" | substr(_rowname,-4,4)=="high" | substr(_rowname,-4,4)=="coll" | substr(_rowname,-4,4)=="grad" | substr(_rowname,-4,4)=="dfem" | substr(_rowname,-4,4)=="cons"  | substr(_rowname,-4,4)=="blue"
gen _count = _n
sort _rowname
merge _rowname using "`summtex'", nokeep
drop _m
sort _count
drop _count
save "brazempl/est/pnad/mmr`yr'sec`sec'`profile'_`infrm'", replace
drop _all
matload mmr`yr'sec`sec'`profile'_`infrm', path(brazempl/est/pnad) over
erase brazempl\est\pnad\mmr`yr'sec`sec'`profile'_`infrm'.dta
local rownum = rowsof(mmr`yr'sec`sec'`profile'_`infrm')
forvalues i = 1/`rownum' {
 forvalues j = 1/2 {
  if mmr`yr'sec`sec'`profile'_`infrm'[`i',`j'] == -999 {
    mat mmr`yr'sec`sec'`profile'_`infrm'[`i',`j'] = 0
    }
   }
  }
* Multiply point estimate by sample mean (multiplication by mean zero when point estimate missing)
mat _xbbrmasc`yr'sec`sec' = mmr`yr'sec`sec'`profile'_`infrm'[1..12,1] '  * mmr`yr'sec`sec'`profile'_`infrm'[1..12,2]
mat _xbbrfemi`yr'sec`sec' = mmr`yr'sec`sec'`profile'_`infrm'[13..25,1] ' * mmr`yr'sec`sec'`profile'_`infrm'[13..25,2]
mat drop mmr`yr'sec`sec'`profile'_`infrm'
}
}
local rownames "indblue fem_indblue xbhatwhite xbhatblue psihat"
foreach sec in 4 {
mat _brcomp`sec' = br90sec`sec'_`profile'_`infrm'in , br97sec`sec'_`profile'_`infrm'in
mat drop br90sec`sec'_`profile'_`infrm'in br97sec`sec'_`profile'_`infrm'in
mat _xbbrmasc`sec' = _xbbrmasc90sec`sec' , _xbbrmasc97sec`sec'
mat _xbbrfemi`sec' = _xbbrfemi90sec`sec' , _xbbrfemi97sec`sec'
mat drop _xbbrmasc90sec`sec' _xbbrmasc97sec`sec' _xbbrfemi90sec`sec' _xbbrfemi97sec`sec'
mat _brpsihat`sec' = br90sec`sec'_mean`profile'_`infrm'out[2,1] , br97sec`sec'_mean`profile'_`infrm'out[2,1]
mat drop br90sec`sec'_mean`profile'_`infrm'out br97sec`sec'_mean`profile'_`infrm'out
mat _brcomp`sec' = _brcomp`sec' \ _xbbrmasc`sec'
mat _brcomp`sec' = _brcomp`sec' \ _xbbrfemi`sec'
mat _brcomp`sec' = _brcomp`sec' \ _brpsihat`sec'
mat drop _xbbrmasc`sec' _xbbrfemi`sec' _brpsihat`sec'
matname _brcomp`sec' `rownames', rows(1..5) explicit
mat braz`profile'_`infrm'in_tbl = _brcomp4
}
local imax = rowsof(braz`profile'_`infrm'in_tbl)
local jmax = colsof(braz`profile'_`infrm'in_tbl)
forvalues i = 1/`imax' {
 forvalues j = 1/`jmax' {
   if braz`profile'_`infrm'in_tbl[`i',`j']==. {
      mat braz`profile'_`infrm'in_tbl[`i',`j']=-999
     }
   }
  }

} /* Close `infrm' loop */


/* BLUE-WHITE COLLAR tabulations: Sectors within Brazil */

foreach infrm in rais informl forml {
mat _seeddta = (1)
drop _all
svmat _seeddta
mat drop _seeddta
rename _seeddta1 _rowname
local j = 0
foreach var in br90sec4 br97sec4 {
  local j = `j' + 1
  local k = 0
  foreach occulvl in indblue {
    local k = `k' + 1    
    local kfem = `k' + 1
    gen `var'_`occulvl'_0 = exp( braz`profile'_`infrm'in_tbl[`k',`j'] * _rowname + braz`profile'_`infrm'in_tbl[3,`j'] + braz`profile'_`infrm'in_tbl[5,`j'] ) 
    gen `var'_`occulvl'_1 = exp( ln(`var'_`occulvl'_0) + braz`profile'_`infrm'in_tbl[`kfem',`j'] * _rowname + braz`profile'_`infrm'in_tbl[4,`j'] )
    replace `var'_`occulvl'_0 = `var'_`occulvl'_0 / exp( braz`profile'_`infrm'in_tbl[3,`j'] + braz`profile'_`infrm'in_tbl[5,`j'] )
    replace `var'_`occulvl'_1 = `var'_`occulvl'_1 / exp( braz`profile'_`infrm'in_tbl[3,`j'] + braz`profile'_`infrm'in_tbl[4,`j'] + braz`profile'_`infrm'in_tbl[5,`j'] )
    }
  }
foreach occulvl in indblue {
 foreach gender in 0 1 {
  foreach yr in 90 97 {
    label var br`yr'sec4_`occulvl'_`gender' "Manufacturing 19`yr'"
    }
   }
  }
reshape long br90sec4_ br97sec4_, i(_rowname) j(bluewhit) string
replace bluewhit = subinstr(bluewhit,"_0",":masc",.)
replace bluewhit = subinstr(bluewhit,"_1",":fem",.)
drop _rowname
rename bluewhit _rowname
foreach var in br90sec4 br97sec4 {
  rename `var'_ `var'
  }
foreach yr in 90 97 {
  label var br`yr'sec4 "Manufacturing 19`yr'"
  }
sort _rowname
compress
save "brazempl/tex/pnad/tables/prflbrsecoccblu_`infrm'_tbl", replace
matload prflbrsecoccblu_`infrm'_tbl, p(brazempl/tex/pnad/tables) over dropall
est2tex prflbrsecoccblu_`infrm', replace dropall preserve ready path(brazempl/tex/pnad/tables) fancy
} /* Close `infrm' loop */


set more off
cd "$home"

