version 8
clear
set matsize 180
set logtype text
set mem 900m
capture set mem 950m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture program drop corrtab
program define corrtab
    args regname yr sec infrm
    predict xbhat if e(sample)
    replace xbhat = xbhat - _coef[_cons]
    gen psihat = _coef[_cons]
    predict eiw, res
    corr lnwage xbhat eiw
    matrix accum corr`infrm'`yr'sec`sec'`regname' = lnwage xbhat eiw, nocons dev means(corr`infrm'`yr'sec`sec'`regname'_means)
    matrix corr`infrm'`yr'sec`sec'`regname'_sdev = corr`infrm'`yr'sec`sec'`regname'_means
    local j 0
    foreach var in lnwage xbhat eiw {
        local j = `j' + 1
        qui summ `var'
        local entry = int(`r(sd)'*10000)/10000
        matrix corr`infrm'`yr'sec`sec'`regname'_sdev[1,`j']=`entry'
        }
    matrix corr`infrm'`yr'sec`sec'`regname'_tbl = corr(corr`infrm'`yr'sec`sec'`regname')
    matrix corr`infrm'`yr'sec`sec'`regname'_tbl = corr`infrm'`yr'sec`sec'`regname'_sdev ' , corr`infrm'`yr'sec`sec'`regname'_tbl
    matrix corr`infrm'`yr'sec`sec'`regname'_tbl = corr`infrm'`yr'sec`sec'`regname'_means ' , corr`infrm'`yr'sec`sec'`regname'_tbl
    matname corr`infrm'`yr'sec`sec'`regname'_tbl mean sdev, columns(1..2) explicit
    drop xbhat psihat eiw
end

capture log close
log using "brazempl/logs/reg-worker-pnad.log", replace

foreach infrm in informl forml all {
 *YR forvalues yr = 90/98 {}  /* 90/98 */
 foreach yr in 90 97 {  /* 90 97 */
  foreach sec in 4  {  /* 1 2 4 5 */
    use "brazempl/pnad/use-pnad-`yr'", clear
    if "`infrm'"=="informl" {
      keep if indinfrm
      }
    if "`infrm'"=="forml" {
      keep if ~indinfrm
      }
    local secname : label sector `sec'
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sector: " in yellow "`sec'" in green " (" in yellow "`secname'" in green ")"
    disp
    * tab sector
    * tab sector, nolab
    keep if sector==`sec'
    sort worker
    foreach var in potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indprim indhigh indprim_alt indhigh_alt indscoll indgrad indblue {
      local dattyp = ""
      if substr("`var'",1,3)=="ind" {
          local dattyp = "byte"
          }
      gen `dattyp' fem_`var' = indfem * `var'
      local lbl : variable label `var'
      local lbl = subinstr("`lbl'"," (at plant)","",.)
      local lbl = subinstr("`lbl'"," Term","",.)
      local lbl = subinstr("`lbl'"," Occupation","",.)
      local lbl = subinstr("`lbl'"," Education","",.)
      local lbl = "Fem. " + "`lbl'" + " Interact."
      label var fem_`var' "`lbl'"
      }
    compress
    drop sector

    reg lnwage potexper potxper2 potxper3 potxper4 indprim indhigh indscoll         indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indprim fem_indhigh fem_indscoll            
    est2vec wage`infrm'`yr'sec`sec', replace vars(potexper potxper2 potxper3 potxper4 tenuryr tenr2 tenr3 tenr4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indprim indhigh indprim_alt indhigh_alt indscoll indgrad indprof indtech indwhit indsklb indunsklb indblue indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_tenuryr fem_tenr2 fem_tenr3 fem_tenr4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8 fem_indprim fem_indhigh fem_indprim_alt fem_indhigh_alt fem_indscoll fem_indgrad fem_indprof fem_indtech fem_indwhit fem_indsklb fem_indunsklb fem_indblue _cons) e(r2 r2_a r2_w r2_o r2_b mss tss corr sigma_u sigma_e df_r df_m) name(yr`yr'sec`sec'potx)

    reg lnwage potexper potxper2 potxper3 potxper4         indhigh indscoll indgrad indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indhigh fem_indscoll fem_indgrad
    est2vec wage`infrm'`yr'sec`sec', addto(wage`infrm'`yr'sec`sec') name(yr`yr'sec`sec'indgrad)
    corrtab indgrad `yr' `sec' `infrm'

    reg lnwage potexper potxper2 potxper3 potxper4         indprim indhigh indscoll indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indprim fem_indhigh fem_indscoll
    est2vec wage`infrm'`yr'sec`sec', addto(wage`infrm'`yr'sec`sec') name(yr`yr'sec`sec'edu)
    corrtab edu `yr' `sec' `infrm'
    
    reg lnwage potexper potxper2 potxper3 potxper4         indprim indhigh indscoll indblue indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indprim fem_indhigh fem_indscoll fem_indblue
    est2vec wage`infrm'`yr'sec`sec', addto(wage`infrm'`yr'sec`sec') name(yr`yr'sec`sec'edublu)
    corrtab edublu `yr' `sec' `infrm'
    
    reg lnwage potexper potxper2 potxper3 potxper4         indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4
    est2vec wage`infrm'`yr'sec`sec', addto(wage`infrm'`yr'sec`sec') name(yr`yr'sec`sec'noedu)
    corrtab noedu `yr' `sec' `infrm'
    
    reg lnwage potexper potxper2 potxper3 potxper4         indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8
    est2vec wage`infrm'`yr'sec`sec', addto(wage`infrm'`yr'sec`sec') name(yr`yr'sec`sec'fuledu)
    corrtab fuledu `yr' `sec' `infrm'
    
    reg lnwage potexper potxper2 potxper3 potxper4         indprim_alt indhigh_alt indscoll indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indprim_alt fem_indhigh_alt fem_indscoll
    est2vec wage`infrm'`yr'sec`sec', addto(wage`infrm'`yr'sec`sec') name(yr`yr'sec`sec'altedu)
    corrtab altedu `yr' `sec' `infrm'
    
    est2tex corr`infrm'`yr'sec`sec'indgrad, replace dropall preserve ready digits(4) fancy path(brazempl/tex/pnad/corr)
    est2tex corr`infrm'`yr'sec`sec'edu, replace dropall preserve ready digits(4) fancy path(brazempl/tex/pnad/corr)
    est2tex corr`infrm'`yr'sec`sec'edublu, replace dropall preserve ready digits(4) fancy path(brazempl/tex/pnad/corr)
    est2tex corr`infrm'`yr'sec`sec'noedu, replace dropall preserve ready digits(4) fancy path(brazempl/tex/pnad/corr)
    est2tex wage`infrm'`yr'sec`sec', replace dropall preserve mark(it) digits(4) fancy path(brazempl/tex/pnad/wage) label
  }
 }
}


* Reformat estimation output tables
foreach infrm in all informl forml {
 foreach var in indgrad edu edublu noedu {
 *YR forvalues yr = 90/98 {}
   foreach yr in 90 97 {
    foreach sec in 4 {
      matload corr`infrm'`yr'sec`sec'`var'_tbl, dropall path(brazempl/tex/pnad/corr) over
      est2tex corr`infrm'`yr'sec`sec'`var', replace dropall preserve ready digits(3) fancy p(brazempl/tex/pnad/corr)
      }
    }
  }
}
 
log close
cd "$home"
