version 8
clear
set matsize 180
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture program drop replexp
program define replexp
  replace mean = mean / 100 if substr(_rowname,-8,8)=="potxper2" | substr(_rowname,-5,5)=="tenr2"
  replace sd = sd / 100 if substr(_rowname,-8,8)=="potxper2" | substr(_rowname,-5,5)=="tenr2"
  replace mean = mean / 1000 if substr(_rowname,-8,8)=="potxper3" | substr(_rowname,-5,5)=="tenr3" 
  replace sd = sd / 1000 if substr(_rowname,-8,8)=="potxper3" | substr(_rowname,-5,5)=="tenr3"
  replace mean = mean / 10000 if substr(_rowname,-8,8)=="potxper4" | substr(_rowname,-5,5)=="tenr4"
  replace sd = sd / 10000 if substr(_rowname,-8,8)=="potxper4" | substr(_rowname,-5,5)=="tenr4"
end


/* Load variable names and save for est2tex */

insheet using "brazempl/tex/regressor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "brazempl/tex/pnad/tables/braz90edu_rowlbl", replace
save "brazempl/tex/pnad/tables/braz90edublu_rowlbl", replace
save "brazempl/tex/pnad/tables/braz97edu_rowlbl", replace
save "brazempl/tex/pnad/tables/braz97edublu_rowlbl", replace
save "brazempl/tex/pnad/tables/lnwmeansdv_pnad_rowlbl", replace
save "brazempl/tex/pnad/tables/prflinfrm_rowlbl", replace
save "brazempl/tex/pnad/tables/summtex_rowlbl", replace
save "brazempl/tex/pnad/tables/summtex90_rowlbl", replace
save "brazempl/tex/pnad/tables/summtex97_rowlbl", replace
clear

foreach infrm in rais informl forml {
  foreach blue in "" "blu" { 
    matload prflbrsecedu`blue'_`infrm'_tbl, p(brazempl/tex/pnad/tables) over dropall
    matload prflbrsecsex`blue'_`infrm'_tbl, p(brazempl/tex/pnad/tables) over dropall
    }
  matload prflbrsecoccblu_`infrm'_tbl, p(brazempl/tex/pnad/tables) over dropall
  }


/* Summary Statistics Workers: Sectors in Brazil 1990 and 1997 */

local yr 90
use "brazempl/tex/pnad/summ/summtex90sec4forml_tbl", clear
foreach var in mean sd {
    replace `var' = . if `var'==-999
    }
replexp
rename mean mean`yr'forml
rename sd sd`yr'forml
merge using "brazempl/tex/pnad/summ/summtex90sec4informl_tbl"
drop _merge
foreach var in mean sd {
    replace `var' = . if `var'==-999
    }
replexp
rename mean mean`yr'informl
rename sd sd`yr'informl
local yr 97
foreach infrm in forml informl {
  merge using "brazempl/tex/pnad/summ/summtex97sec4`infrm'_tbl"
  drop _merge
  foreach var in mean sd {
      replace `var' = . if `var'==-999
      }
  replexp
  rename mean mean`yr'`infrm'
  rename sd sd`yr'`infrm'
  }
drop if mean90forml==. & mean90informl==. & mean97forml==. & mean97informl==.
save "brazempl/tex/pnad/tables/summtex_tbl", replace
drop _all
matload summtex_tbl, path(brazempl/tex/pnad/tables) over
est2tex summtex, replace dropall preserve ready p(brazempl/tex/pnad/tables) fancy extracols(2 4 6)
local rows = rowsof(summtex_tbl)
mat summtex90_tbl = summtex_tbl[1..`rows',1..4]
mat summtex97_tbl = summtex_tbl[1..`rows',5..8]
est2tex summtex90, replace dropall preserve ready p(brazempl/tex/pnad/tables) fancy extracols(2)
est2tex summtex97, replace dropall preserve ready p(brazempl/tex/pnad/tables) fancy extracols(2)


/* Estimation Tables for Workers: Brazil by Sector, 1990 and 1997 */

local sec 4
foreach regname in edu edublu {
foreach yr in 90 97 {
  foreach infrm in rais forml informl {
    tempfile y`yr'i`infrm'`regname'
    use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
    gen int _brno = _n
    keep _rowname yr`yr'sec`sec'`regname' _brno
    rename yr`yr'sec`sec'`regname' yr`yr'sec`sec'`infrm'
    sort _brno
    compress
    save `y`yr'i`infrm'`regname''
    }
use `y`yr'irais`regname''
foreach infrm in forml informl {
    sort _brno
    merge _brno using `y`yr'i`infrm'`regname''
    drop _m
    }
sort _brno
drop _brno
drop if yr`yr'sec4rais==-999 & yr`yr'sec4forml==-999 & yr`yr'sec4informl==-999
drop if _rowname[_n-1]=="_cons"
drop if _rowname=="_cons"
drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)" & _rowname~="e(r2_w)"
save "brazempl/tex/pnad/tables/braz`yr'`regname'_tbl", replace
drop _all
matload braz`yr'`regname'_tbl, path(brazempl/tex/pnad/tables) over
est2tex braz`yr'`regname', replace dropall preserve ready mark(it) fancy path(brazempl/tex/pnad/tables)
}
mat braz`regname'_tbl = braz90`regname'_tbl , braz97`regname'_tbl
est2tex braz`regname', replace dropall preserve ready mark(it) fancy path(brazempl/tex/pnad/tables)
}


/* Combine wage levels and variability by informality for manufacturing */

* lnwmeansdv_pnad based on manufacturing only
foreach yr in 90 97 {
  foreach var in indfem indnocoll {
    matload lnwmean`yr'`var'_tbl, p(brazempl/tex/v1/summ) over dropall
    matload lnwmean`yr'`var'_forml_tbl, p(brazempl/tex/pnad/summ) over dropall
    matload lnwmean`yr'`var'_informl_tbl, p(brazempl/tex/pnad/summ) over dropall
    matload sdv`yr'`var'_tbl, p(brazempl/tex/v1/summ) over dropall
    matload sdv`yr'`var'_forml_tbl, p(brazempl/tex/pnad/summ) over dropall
    matload sdv`yr'`var'_informl_tbl, p(brazempl/tex/pnad/summ) over dropall
    }
  }
foreach yr in 90 97 {
  matload summtex`yr'sec4_tbl, p(brazempl/tex/v1/summ) over
  matload summtex`yr'sec4forml_tbl, p(brazempl/tex/pnad/summ) over
  matload summtex`yr'sec4informl_tbl, p(brazempl/tex/pnad/summ) over
  }
mat lnwmeansdv_pnad = J(10,6,-999)
matname lnwmeansdv_pnad rais pnadform pnadinf rais pnadform pnadinf, columns(1..6) explicit
mat coleq lnwmeansdv_pnad = lnmeanw lnmeanw lnmeanw sdv sdv sdv
matname lnwmeansdv_pnad 90alloc 97alloc 90indfem:0 90indfem:1 97indfem:0 97indfem:1 90indnocoll:0 90indnocoll:1 97indnocoll:0 97indnocoll:1, rows(1..10) explicit

local row = -1
foreach var in indfem indnocoll {
  local row = `row' + 4
  local subrow = -2
  foreach yr in 90 97 {
    local subrow = `subrow' + 2
    mat lnwmeansdv_pnad[`row'+`subrow',1]   = lnwmean`yr'`var'_tbl[1,4]
    mat lnwmeansdv_pnad[`row'+`subrow'+1,1] = lnwmean`yr'`var'_tbl[2,4]
    mat lnwmeansdv_pnad[`row'+`subrow',2]   = lnwmean`yr'`var'_forml_tbl[1,1]
    mat lnwmeansdv_pnad[`row'+`subrow'+1,2] = lnwmean`yr'`var'_forml_tbl[2,1]
    mat lnwmeansdv_pnad[`row'+`subrow',3]   = lnwmean`yr'`var'_informl_tbl[1,1]
    mat lnwmeansdv_pnad[`row'+`subrow'+1,3] = lnwmean`yr'`var'_informl_tbl[2,1]
    mat lnwmeansdv_pnad[`row'+`subrow',4]   = sdv`yr'`var'_tbl[1,4]
    mat lnwmeansdv_pnad[`row'+`subrow'+1,4] = sdv`yr'`var'_tbl[2,4]
    mat lnwmeansdv_pnad[`row'+`subrow',5]   = sdv`yr'`var'_forml_tbl[1,1]
    mat lnwmeansdv_pnad[`row'+`subrow'+1,5] = sdv`yr'`var'_forml_tbl[2,1]
    mat lnwmeansdv_pnad[`row'+`subrow',6]   = sdv`yr'`var'_informl_tbl[1,1]
    mat lnwmeansdv_pnad[`row'+`subrow'+1,6] = sdv`yr'`var'_informl_tbl[2,1]
    }
  }
mat lnwmeansdv_pnad[1,1] = summtex90sec4_tbl[1,1]
mat lnwmeansdv_pnad[2,1] = summtex97sec4_tbl[1,1]
mat lnwmeansdv_pnad[1,2] = summtex90sec4forml_tbl[1,1]
mat lnwmeansdv_pnad[2,2] = summtex97sec4forml_tbl[1,1]
mat lnwmeansdv_pnad[1,3] = summtex90sec4informl_tbl[1,1]
mat lnwmeansdv_pnad[2,3] = summtex97sec4informl_tbl[1,1]
mat lnwmeansdv_pnad[1,4] = summtex90sec4_tbl[1,2]
mat lnwmeansdv_pnad[2,4] = summtex97sec4_tbl[1,2]
mat lnwmeansdv_pnad[1,5] = summtex90sec4forml_tbl[1,2]
mat lnwmeansdv_pnad[2,5] = summtex97sec4forml_tbl[1,2]
mat lnwmeansdv_pnad[1,6] = summtex90sec4informl_tbl[1,2]
mat lnwmeansdv_pnad[2,6] = summtex97sec4informl_tbl[1,2]

mat rename lnwmeansdv_pnad lnwmeansdv_pnad_tbl 
est2tex lnwmeansdv_pnad, replace dropall preserve ready path(brazempl/tex/pnad/tables) fancy extracols(3)

foreach yr in 90 97 {
  foreach var in indfem indnocoll {
    mat drop lnwmean`yr'`var'_tbl lnwmean`yr'`var'_forml_tbl lnwmean`yr'`var'_informl_tbl
    mat drop sdv`yr'`var'_tbl sdv`yr'`var'_forml_tbl sdv`yr'`var'_informl_tbl
    }
  mat drop summtex`yr'sec4_tbl summtex`yr'sec4forml_tbl summtex`yr'sec4informl_tbl
  }


/* Wage profile tables */

local blue = ""

foreach infrm in rais informl forml {
  local cols = colsof(prflbrsecedu`blue'_`infrm'_tbl)
  local colnames : colfullnames prflbrsecedu`blue'_`infrm'_tbl
  mat prfl`infrm'_tbl = J(1,`cols',1) \ prflbrsecedu`blue'_`infrm'_tbl[1..3,1..`cols'] \ J(1,`cols',1) \ prflbrsecedu`blue'_`infrm'_tbl[4..6,1..`cols'] \ prflbrsecsex_`infrm'_tbl[1..2,1..`cols']
  matname prfl`infrm'_tbl grad:masc, rows(1) explicit
  matname prfl`infrm'_tbl grad:fem, rows(5) explicit 
  matname prfl`infrm'_tbl `colnames', columns(1..`cols') explicit
  forvalues col = 1/`cols' {
   foreach row in 1 2 4 {
     mat prfl`infrm'_tbl[`row',`col'] = prfl`infrm'_tbl[`row',`col'] / prfl`infrm'_tbl[3,`col']
     }
   mat prfl`infrm'_tbl[3,`col'] = prfl`infrm'_tbl[3,`col'] / prfl`infrm'_tbl[3,`col']
   foreach row in 5 6 8 {
     mat prfl`infrm'_tbl[`row',`col'] = prfl`infrm'_tbl[`row',`col'] / prfl`infrm'_tbl[7,`col']
     }
   mat prfl`infrm'_tbl[7,`col'] = prfl`infrm'_tbl[7,`col'] / prfl`infrm'_tbl[7,`col']
   }
  }
mat prflinfrm`blue'_tbl = prflrais_tbl , prflforml_tbl , prflinforml_tbl
mat coleq prflinfrm`blue'_tbl = rais rais forml forml informl informl
est2tex prflinfrm`blue', replace dropall preserve ready path(brazempl/tex/pnad/tables) fancy extracols(2 4)

local blue = "blu" 

foreach infrm in rais informl forml {
  local cols = colsof(prflbrsecedu`blue'_`infrm'_tbl)
  local colnames : colfullnames prflbrsecedu`blue'_`infrm'_tbl
  mat prfl`infrm'_tbl = J(1,`cols',1) \ prflbrsecedu`blue'_`infrm'_tbl[1..3,1..`cols'] \ J(1,`cols',1) \ prflbrsecedu`blue'_`infrm'_tbl[4..6,1..`cols'] \ prflbrsecoccblu_`infrm'_tbl[2,1..`cols'] \ prflbrsecoccblu_`infrm'_tbl[1,1..`cols'] \ prflbrsecsex_`infrm'_tbl[1..2,1..`cols']
  matname prfl`infrm'_tbl grad:masc, rows(1) explicit
  matname prfl`infrm'_tbl grad:fem, rows(5) explicit 
  matname prfl`infrm'_tbl `colnames', columns(1..`cols') explicit
  forvalues col = 1/`cols' {
   foreach row in 1 2 4 {
     mat prfl`infrm'_tbl[`row',`col'] = prfl`infrm'_tbl[`row',`col'] / prfl`infrm'_tbl[3,`col']
     }
   mat prfl`infrm'_tbl[3,`col'] = prfl`infrm'_tbl[3,`col'] / prfl`infrm'_tbl[3,`col']
   foreach row in 5 6 8 {
     mat prfl`infrm'_tbl[`row',`col'] = prfl`infrm'_tbl[`row',`col'] / prfl`infrm'_tbl[7,`col']
     }
   mat prfl`infrm'_tbl[7,`col'] = prfl`infrm'_tbl[7,`col'] / prfl`infrm'_tbl[7,`col']
   }
  }
mat prflinfrm`blue'_tbl = prflrais_tbl , prflforml_tbl , prflinforml_tbl
mat coleq prflinfrm`blue'_tbl = rais rais forml forml informl informl
est2tex prflinfrm`blue', replace dropall preserve ready path(brazempl/tex/pnad/tables) fancy extracols(2 4)
