version 8
clear
set matsize 300
set logtype text
set mem 900m
capture set mem 950m
set more off
adopath + "brazempl/%stata/ado"

cd "$root"

capture mkdir "brazempl/tex/pnad/kleinspady"

local sec 4

capture log close
log using "brazempl/logs/kleinspady-pnad.log", replace

foreach regtype in kleinspady klnspdblu {

if "`regtype'"=="kleinspady" {
  global selvars "potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8"
  }
if "`regtype'"=="klnspdblu" {
  global selvars "potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indblu indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8 fem_indblu"
  }

*YR forvalues yr = 90/98 {}  /* 90/98 */
foreach yr in 90 97 {  /* 90 97 */
    use "brazempl/pnad/use-pnad-`yr'", clear
    replace lnwage = . if indinfrm==1
    gen byte indselct = 1 - indinfrm
    label var indselct "Formality Selection"
    local secname : label sector `sec'
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sector: " in yellow "`sec'" in green " (" in yellow "`secname'" in green ")"
    disp
    * tab sector
    * tab sector, nolab
    keep if sector==`sec'
    sort worker
    foreach var in potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indprim indhigh indprim_alt indhigh_alt indscoll indgrad indblue {
      local dattyp = ""
      if substr("`var'",1,3)=="ind" {
          local dattyp = "byte"
          }
      gen `dattyp' fem_`var' = indfem * `var'
      local lbl : variable label `var'
      local lbl = subinstr("`lbl'"," (at plant)","",.)
      local lbl = subinstr("`lbl'"," Term","",.)
      local lbl = subinstr("`lbl'"," Occupation","",.)
      local lbl = subinstr("`lbl'"," Education","",.)
      local lbl = "Fem. " + "`lbl'" + " Interact."
      label var fem_`var' "`lbl'"
      }
    compress
    drop sector

    // Initial values
    tempname binit
    probit indselct $selvars, nocons
    local benchb = _b[potexper]
    constraint define 1 potexper=`benchb'
    mat `binit' = e(b)
    * predict double _ini_xb, xb
    * qui summ _ini_xb, meanonly
    global width = r(N)^(-1/7)  /* Klein and Spady (Ecma 1993), condition (C8) requires r(N)^(-1/6) < `width' < r(N)^(-1/8) */

    // Klein-Spady estimator based on Nadaraya-Watson kernel
    ml model d0 nwkleinspady_d2 (indselct = $selvars, nocons), constraints(1)
    ml init `binit', skip
    capture noi ml maximize, difficult iter(10) tolerance(1e-4) ltolerance(1e-5)

    est2vec `regtype'`yr'sec`sec', replace vars(lnwage:potexper lnwage:potxper2 lnwage:potxper3 lnwage:potxper4 lnwage:tenuryr lnwage:tenr2 lnwage:tenr3 lnwage:tenr4 lnwage:indschlg1 lnwage:indschlg2 lnwage:indschlg3 lnwage:indschlg4 lnwage:indschlg5 lnwage:indschlg6 lnwage:indschlg7 lnwage:indschlg8 lnwage:indprim lnwage:indhigh lnwage:indprim_alt lnwage:indhigh_alt lnwage:indscoll lnwage:indgrad lnwage:indprof lnwage:indtech lnwage:indwhit lnwage:indsklb lnwage:indunsklb lnwage:indblue lnwage:indfem lnwage:fem_potexper lnwage:fem_potxper2 lnwage:fem_potxper3 lnwage:fem_potxper4 lnwage:fem_tenuryr lnwage:fem_tenr2 lnwage:fem_tenr3 lnwage:fem_tenr4 lnwage:fem_indschlg1 lnwage:fem_indschlg2 lnwage:fem_indschlg3 lnwage:fem_indschlg4 lnwage:fem_indschlg5 lnwage:fem_indschlg6 lnwage:fem_indschlg7 lnwage:fem_indschlg8 lnwage:fem_indprim lnwage:fem_indhigh lnwage:fem_indprim_alt lnwage:fem_indhigh_alt lnwage:fem_indscoll lnwage:fem_indgrad lnwage:fem_indprof lnwage:fem_indtech lnwage:fem_indwhit lnwage:fem_indsklb lnwage:fem_indunsklb lnwage:fem_indblue lnwage:_cons indselct:potexper indselct:potxper2 indselct:potxper3 indselct:potxper4 indselct:indschlg1 indselct:indschlg2 indselct:indschlg3 indselct:indschlg4 indselct:indschlg5 indselct:indschlg6 indselct:indschlg7 indselct:indschlg8 indselct:indprof indselct:indtech indselct:indwhit indselct:indsklb indselct:indblue indselct:indfem indselct:fem_potexper indselct:fem_potxper2 indselct:fem_potxper3 indselct:fem_potxper4 indselct:fem_indschlg1 indselct:fem_indschlg2 indselct:fem_indschlg3 indselct:fem_indschlg4 indselct:fem_indschlg5 indselct:fem_indschlg6 indselct:fem_indschlg7 indselct:fem_indschlg8 indselct:fem_indprof indselct:fem_indtech indselct:fem_indwhit indselct:fem_indsklb indselct:fem_indblue indselct:_cons) e(N N_cens r2 r2_a r2_w r2_o r2_b mss tss corr sigma_u sigma_e df_r df_m) name(yr`yr'sec`sec'potx)
    est2tex `regtype'`yr'sec`sec', replace dropall preserve mark(it) digits(4) fancy path(brazempl/tex/pnad/kleinspady) label

  } /* close `yr' loop */

} /* close `regtype' loop */

log close
cd "$home"
