version 8
clear
set matsize 300
set logtype text
set mem 900m
capture set mem 950m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture mkdir "brazempl/tex/pnad"
capture mkdir "brazempl/tex/pnad/nonparam"

local sec 4

capture log close
log using "brazempl/logs/nonparam-pnad-crossval.log", replace

foreach regtype in nonparam nonpblu {

*YR forvalues yr = 90/98 {}  /* 90/98 */
foreach yr in 90 97 {  /* 90 97 */
    use "brazempl/pnad/use-pnad-`yr'", clear
    replace lnwage = . if indinfrm==1
    qui gen byte indselct = 1 - indinfrm
    label var indselct "Formality Selection"
    local secname : label sector `sec'
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sector: " in yellow "`sec'" in green " (" in yellow "`secname'" in green "), Regression type: " in yellow "`regtype'"
    disp
    * tab sector
    * tab sector, nolab
    keep if sector==`sec'
    sort worker
    foreach var in potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indprim indhigh indprim_alt indhigh_alt indscoll indgrad indblue {
      local dattyp = ""
      if substr("`var'",1,3)=="ind" {
          local dattyp = "byte"
          }
      qui gen `dattyp' fem_`var' = indfem * `var'
      local lbl : variable label `var'
      local lbl = subinstr("`lbl'"," (at plant)","",.)
      local lbl = subinstr("`lbl'"," Term","",.)
      local lbl = subinstr("`lbl'"," Occupation","",.)
      local lbl = subinstr("`lbl'"," Education","",.)
      local lbl = "Fem. " + "`lbl'" + " Interact."
      label var fem_`var' "`lbl'"
      }
    compress
    drop sector

    if "`regtype'"=="nonparam" {
      global selvars "potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8"
      forvalues i = 1/4 {
        foreach var in indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indfem {
          local pname = "potx`i'"
          local vname = subinstr("`var'","ind","",.)
          if `i'==1  qui gen set1_`pname'_`vname' = potexper * `var'
          else       qui gen set1_`pname'_`vname' = potxper`i' * `var'
          }
        foreach var in indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 {
          local pname = "fem_potx`i'"
          local vname = subinstr("`var'","ind","",.)
          if `i'==1  qui gen set2_`pname'_`vname' = fem_potexper * `var'
          else       qui gen set2_`pname'_`vname' = fem_potxper`i' * `var'
          }
        }
      }
    if "`regtype'"=="nonpblu" {
      global selvars "potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indblu indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8 fem_indblu"
      forvalues i = 1/4 {
        foreach var in indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indblu indfem {
          local pname = "potx`i'"
          local vname = subinstr("`var'","ind","",.)
          if `i'==1  qui gen set1_`pname'_`vname' = potexper * `var'
          else       qui gen set1_`pname'_`vname' = potxper`i' * `var'
          }
        foreach var in indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indblu {
          local pname = "fem_potx`i'"
          local vname = subinstr("`var'","ind","",.)
          if `i'==1  qui gen set2_`pname'_`vname' = fem_potexper * `var'
          else       qui gen set2_`pname'_`vname' = fem_potxper`i' * `var'
          }
        }
      }

    /* Leave-one-out cross validation */

    * number of observations
    qui gen obsid = _n
    label var obsid "Running observation number"
    qui compress obsid
    local obstot = _N

    forvalues poly = 1/3 {
      qui gen double pscpoly`poly' = .
      forvalues num = 1/`obstot' {

        if `poly'==1       qui reg indselct $selvars
        else if `poly'==2  qui reg indselct $selvars set1_*, nocons
        else if `poly'==3  qui reg indselct $selvars set1_* set2_*, nocons
    
        * predict propensity score for omitted observation;
        qui predict double _psc, xb
        qui replace pscpoly`poly' = _psc if obsid==`num'
        drop _psc
        * summ psc
        }
      }

    /* collapse sums of squared errors to table */
    /*------------------------------------------*/

    local r2dg = substr("`reg'",1,2)
    forvalues poly = 1/3 {
      qui gen double avgse`poly' = (indselct - pscpoly`poly')^2
      }  /* close poly loop */
    collapse (mean) avgse?, fast
    qui gen str _rowname = "`regtype':19`yr'"
    save "brazempl/tex/pnad/nonparam/crossval_tbl.dta", replace
    matload crossval_tbl, p(brazempl/tex/pnad/nonparam) over dropall
    mat rename crossval_tbl `regtype'`yr'_tbl
    
    } /* close `yr' loop */

  } /* close `regtype' loop */

/* create final table */
/*--------------------*/

mat crossval_tbl = nonparam90_tbl \ nonpblu90_tbl \ nonparam97_tbl \ nonpblu97_tbl
est2tex crossval, ready replace dropall preserve path(brazempl/tex/pnad/nonparam) fancy

log close
cd "$home"
