version 8
clear
set matsize 300
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

/* Load variable names and save for est2tex */

insheet using "brazempl/tex/regressor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "brazempl/tex/heckman/tables/selection_rowlbl", replace
save "brazempl/tex/heckman/tables/selshort_rowlbl", replace
save "brazempl/tex/heckman/tables/pnadselcomp_rowlbl", replace
save "brazempl/tex/heckman/tables/pnadraisselblu_rowlbl", replace
save "brazempl/tex/heckman/tables/raisseledu_rowlbl", replace
save "brazempl/tex/heckman/tables/raisselcomp_rowlbl", replace
save "brazempl/tex/heckman/tables/prflselcomp_rowlbl", replace
clear


/* Load Profile Matrices */

foreach profile in edu occu sex {
 foreach type in comp brsec {
  matload prfl`type'`profile'_tbl, p(brazempl/tex/heckman/tables) over dropall
  * matload prfl`type'plain`profile'_tbl, p(brazempl/tex/heckman/tables) over dropall
  }
 }


/* Estimation Tables for Workers: Brazil by Sector, 1990 and 1997 */

local sec 4
local regname edu
foreach yr in 90 97 {
  foreach regtype in heckman heckblu {
    tempfile y`yr'`regtype'
    use "brazempl/tex/pnad/wage/wage`regtype'`yr'sec`sec'_tbl", clear
    drop if substr(_rowname[_n-1],1,7)=="lnwage:" | substr(_rowname[_n-1],1,6)=="mills:"
    drop if substr(_rowname,1,7)=="lnwage:" | substr(_rowname,1,6)=="mills:"
    drop if substr(_rowname[_n-1],-7,7)=="indprof" | substr(_rowname[_n-1],-7,7)=="indtech" | substr(_rowname[_n-1],-7,7)=="indwhit" | substr(_rowname[_n-1],-7,7)=="indsklb" | substr(_rowname[_n-1],-7,7)=="indunsklb"
    drop if substr(_rowname,-7,7)=="indprof" | substr(_rowname,-7,7)=="indtech" | substr(_rowname,-7,7)=="indwhit" | substr(_rowname,-7,7)=="indsklb" | substr(_rowname,-7,7)=="indunsklb"
    drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)" & _rowname~="e(N_cens)"
    replace _rowname = subinstr(_rowname,"indselct:","",.)
    gen int _brno = _n
    keep _rowname yr`yr'sec`sec'`regname' _brno
    rename yr`yr'sec`sec'`regname' yr`yr'sec`sec'`regtype'
    sort _brno
    compress
    save `y`yr'`regtype''
    }
  }
local regtype rais1stage
foreach yr in 90 97 {
    tempfile y`yr'`regtype'
    use "brazempl/tex/heckman/wage/wageheckman`yr'sec`sec'_tbl", clear
    drop if substr(_rowname[_n-1],1,7)=="lnwage:" | substr(_rowname[_n-1],1,6)=="mills:"
    drop if substr(_rowname,1,7)=="lnwage:" | substr(_rowname,1,6)=="mills:"
    drop if  yr`yr'sec4blupnad==-999 & yr`yr'sec4blureg==-999 &  yr`yr'sec4bluxtreg==-999 &  yr`yr'sec4edureg==-999 &  yr`yr'sec4eduxtreg==-999
    drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)" & _rowname~="e(N_cens)"
    replace _rowname = subinstr(_rowname,"indselct:","",.)
    gen int _brno = _n
    keep _rowname yr`yr'sec`sec'blupnad _brno
    rename yr`yr'sec`sec'blupnad yr`yr'sec`sec'`regtype'
    sort _brno
    compress
    save `y`yr'`regtype''
    }
use `y90heckblu'
  foreach regtype in rais1stage heckman {
    sort _brno
    merge _brno using `y90`regtype''
    drop _m
  }
  foreach regtype in heckblu rais1stage heckman {
    sort _brno
    merge _brno using `y97`regtype''
    drop _m    
    }
sort _brno
drop _brno
drop if yr90sec4heckblu==-999 & yr90sec4rais1stage==-999 & yr90sec4heckman==-999 & yr97sec4heckblu==-999 & yr97sec4rais1stage==-999 & yr97sec4heckman==-999
drop yr90sec4rais1stage yr97sec4rais1stage
save "brazempl/tex/heckman/tables/selection_tbl", replace
drop _all
matload selection_tbl, path(brazempl/tex/heckman/tables) over
est2tex selection, replace dropall preserve ready mark(it) fancy path(brazempl/tex/heckman/tables) extracols(2)

matorder selection_tbl, matrix(selshort) ifc(yr90sec4heckblu yr97sec4heckblu) over
local femrow = rownumb(selshort,"indfem")
matname selshort fem__cons, rows(`femrow') explicit
local varlst : rownames selshort
local varlst : list uniq varlst
local rmvlst "e(N) e(N_cens) r(chi2) r(df_m) r(r2_p) _se"
local varlst : list varlst - rmvlst
* disp "`varlst'"
local vars : word count `varlst'
local selst ""
local masclst ""
local femilst ""
tokenize `varlst'
forvalues i = 1/`vars' {
  local col = `i'*2
  matname selshort _se_``i'', rows(`col') explicit
  local selst "`selst' _se_``i''"
  if substr("``i''",1,4)~="fem_" {
    local masclst "`masclst' ``i''"
    local femilst "`femilst' fem_``i''"
    }
  }
matorder selshort, matrix(selshort_b) ifr(`varlst')
matorder selshort, matrix(selshort_se) ifr(`selst')
matorder selshort, matrix(selshort_e) ifr(e(N) e(N_cens) r(chi2) r(df_m) r(r2_p))
matrix rownames selshort_se = `varlst'
* disp "`masclst'"
foreach type in b se {
  matorder selshort_`type', matrix(selshort_masc_`type') ifr(`masclst')
  matorder selshort_`type', matrix(selshort_femi_`type') ifr(`femilst')
  mat selshort_`type' = selshort_masc_`type' , selshort_femi_`type'
  mat coleq selshort_`type' = masc masc femi femi
  matorder selshort_`type', m(selshort_`type') ifc(masc:yr90sec4heckblu femi:yr90sec4heckblu masc:yr97sec4heckblu femi:yr97sec4heckblu) over
  mat drop selshort_masc_`type' selshort_femi_`type'
  matrix colnames selshort_`type' = :masc_yr90sec4heckblu :femi_yr90sec4heckblu :masc_yr97sec4heckblu :femi_yr97sec4heckblu
  }
local type "e"
  mat selshort_`type' = selshort_`type' , selshort_`type'
  mat coleq selshort_`type' = masc masc femi femi
  matorder selshort_`type', m(selshort_`type') ifc(masc:yr90sec4heckblu femi:yr90sec4heckblu masc:yr97sec4heckblu femi:yr97sec4heckblu) over
  matrix colnames selshort_`type' = :masc_yr90sec4heckblu :femi_yr90sec4heckblu :masc_yr97sec4heckblu :femi_yr97sec4heckblu
est2tex selshort, replace dropall preserve mark(it) fancy path(brazempl/tex/heckman/tables) extracols(2)

local sec 4
foreach yr in 90 97 {
    tempfile y`yr'select
    use "brazempl/tex/heckman/wage/wageheckman`yr'sec4_tbl", clear
    drop if substr(_rowname,1,2)=="e(" & substr(_rowname,1,3)~="e(N"
    drop if substr(_rowname[_n-1],1,9)=="indselct:"
    drop if substr(_rowname,1,9)=="indselct:"
    replace _rowname = subinstr(_rowname,"lnwage:","",.)
    keep _rowname yr`yr'sec`sec'blupnad
    rename yr`yr'sec`sec'blupnad yr`yr'sec`sec'select
    gen int _brno = _n
    sort _brno
    compress
    save `y`yr'select'
    }
local infrm "forml"
foreach yr in 90 97 {
    tempfile y`yr'nosel
    use "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl", clear
    drop if substr(_rowname,1,2)=="e(" & substr(_rowname,1,3)~="e(N"
    keep _rowname yr`yr'sec`sec'edublu
    rename yr`yr'sec`sec'edublu yr`yr'sec`sec'nosel
    gen int _brno = _n
    replace _brno = _brno + 2 if substr(_rowname,1,2)=="e("  /* Shift for mills:lambda */
    sort _brno
    compress
    save `y`yr'nosel'
    }
use `y90select'
    sort _brno
    merge _brno using `y90nosel'
    drop _m
    foreach regname in select nosel {
      sort _brno
      merge _brno using `y97`regname''
      drop _m     
      }
sort _brno
drop _brno
drop if yr90sec4select==-999 & yr90sec4nosel==-999 & yr97sec4select==-999 & yr97sec4nosel==-999
save "brazempl/tex/heckman/tables/pnadselcomp_tbl", replace
drop _all
matload pnadselcomp_tbl, path(brazempl/tex/heckman/tables) over
est2tex pnadselcomp, replace dropall preserve ready mark(it) fancy path(brazempl/tex/heckman/tables) extracols(2)

local sec 4
foreach yr in 90 97 {
  foreach regname in blureg blupnad {
    tempfile y`yr'`regname'
    use "brazempl/tex/heckman/wage/wageheckman`yr'sec4_tbl", clear
    gen int _brno = _n
    keep _rowname yr`yr'sec`sec'`regname' _brno
    sort _brno
    compress
    save `y`yr'`regname''
    }
  }
use `y90blureg'
    sort _brno
    merge _brno using `y90blupnad'
    drop _m
    foreach regname in blureg blupnad {
      sort _brno
      merge _brno using `y97`regname''
      drop _m     
      }
sort _brno
drop _brno
drop if yr90sec4blureg==-999 & yr90sec4blupnad==-999 & yr97sec4blureg==-999 & yr97sec4blupnad==-999
drop if substr(_rowname[_n-1],1,9)=="indselct:"
drop if substr(_rowname,1,9)=="indselct:"
drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)" & _rowname~="e(N_cens)" & _rowname~="e(chi2)" & _rowname~="e(p)"
replace _rowname = subinstr(_rowname,"lnwage:","",.)
save "brazempl/tex/heckman/tables/pnadraisselblu_tbl", replace
drop _all
matload pnadraisselblu_tbl, path(brazempl/tex/heckman/tables) over
est2tex pnadraisselblu, replace dropall preserve ready mark(it) fancy path(brazempl/tex/heckman/tables) extracols(2)

local sec 4
foreach yr in 90 97 {
  foreach regname in eduxtreg edureg {
    tempfile y`yr'`regname'
    use "brazempl/tex/heckman/wage/wageheckman`yr'sec4_tbl", clear
    gen int _brno = _n
    keep _rowname yr`yr'sec`sec'`regname' _brno
    sort _brno
    compress
    save `y`yr'`regname''
    }
  }
use `y90eduxtreg'
    sort _brno
    merge _brno using `y90edureg'
    drop _m
    foreach regname in eduxtreg edureg {
      sort _brno
      merge _brno using `y97`regname''
      drop _m     
      }
sort _brno
drop _brno
drop if yr90sec4eduxtreg==-999 & yr90sec4edureg==-999 & yr97sec4eduxtreg==-999 & yr97sec4edureg==-999
drop if substr(_rowname[_n-1],1,9)=="indselct:"
drop if substr(_rowname,1,9)=="indselct:"
drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)" & _rowname~="e(N_cens)" & _rowname~="e(chi2)" & _rowname~="e(p)"
replace _rowname = subinstr(_rowname,"lnwage:","",.)
save "brazempl/tex/heckman/tables/raisseledu_tbl", replace
drop _all
matload raisseledu_tbl, path(brazempl/tex/heckman/tables) over
est2tex raisseledu, replace dropall preserve ready mark(it) fancy path(brazempl/tex/heckman/tables) extracols(2)

local sec 4
local regname eduxtreg
foreach yr in 90 97 {
  tempfile y`yr'select
  use "brazempl/tex/heckman/wage/wageheckman`yr'sec`sec'_tbl", clear
  keep _rowname yr`yr'sec`sec'eduxtreg
  rename yr`yr'sec`sec'eduxtreg yr`yr'sec`sec'select
  drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)"
  drop if substr(_rowname[_n-1],1,9)=="indselct:"
  drop if substr(_rowname,1,9)=="indselct:"
  replace _rowname = subinstr(_rowname,"lnwage:","",.)
  drop if substr(_rowname[_n-1],-7,7)=="indblue"
  drop if substr(_rowname,-7,7)=="indblue"
  gen int _brno = _n
  sort _brno
  compress
  save `y`yr'select'
  }
foreach yr in 90 97 {
  tempfile y`yr'nosel
  use "brazempl/tex/v1/wage/wage`yr'sec`sec'_tbl", clear
  drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)"
  keep _rowname yr`yr'sec`sec'edu
  rename yr`yr'sec`sec'edu yr`yr'sec`sec'nosel
  gen int _brno = _n
  replace _brno = _brno + 2 if substr(_rowname,1,2)=="e("  /* Shift for mills:lambda */
  sort _brno
  compress
  save `y`yr'nosel'
  }
use `y90select'
    sort _brno
    merge _brno using `y90nosel'
    drop _m
    foreach selname in select nosel {
      sort _brno
      merge _brno using `y97`selname''
      drop _m     
      }
sort _brno
drop _brno
drop if yr90sec4select==-999 & yr90sec4nosel==-999 & yr97sec4select==-999 & yr97sec4nosel==-999
save "brazempl/tex/heckman/tables/raisselcomp_tbl", replace
drop _all
matload raisselcomp_tbl, path(brazempl/tex/heckman/tables) over
est2tex raisselcomp, replace dropall preserve ready mark(it) fancy path(brazempl/tex/heckman/tables) extracols(2)


/* Profile Tables for education, occupation, gender: Brazil 1990 and 1997 */

* Wage profile tables
foreach type in comp brsec {
  local cols = colsof(prfl`type'edu_tbl)
  local colnames : colfullnames prfl`type'edu_tbl
  mat prfl`type'_tbl = J(1,`cols',1) \ prfl`type'edu_tbl[1..3,1..`cols'] \ J(1,`cols',1) \ prfl`type'edu_tbl[4..6,1..`cols'] \ prfl`type'occu_tbl[1..4,1..`cols'] \ J(1,`cols',1) \ prfl`type'occu_tbl[5..8,1..`cols'] \ J(1,`cols',1) \ prfl`type'sex_tbl[1..2,1..`cols']
  matname prfl`type'_tbl grad:masc, rows(1) explicit
  matname prfl`type'_tbl grad:fem, rows(5) explicit 
  matname prfl`type'_tbl unskl:masc, rows(13) explicit
  matname prfl`type'_tbl unskl:fem, rows(18) explicit
  matname prfl`type'_tbl `colnames', columns(1..`cols') explicit
  forvalues col = 1/`cols' {
   foreach row in 1 2 4 {
     mat prfl`type'_tbl[`row',`col'] = prfl`type'_tbl[`row',`col'] / prfl`type'_tbl[3,`col']
     }
   mat prfl`type'_tbl[3,`col'] = prfl`type'_tbl[3,`col'] / prfl`type'_tbl[3,`col']
   foreach row in 5 6 8 {
     mat prfl`type'_tbl[`row',`col'] = prfl`type'_tbl[`row',`col'] / prfl`type'_tbl[7,`col']
     }
   mat prfl`type'_tbl[7,`col'] = prfl`type'_tbl[7,`col'] / prfl`type'_tbl[7,`col']
   }
  }
mat prflbrsec_tbl = prflbrsec_tbl[1..rowsof(prflbrsec_tbl),5..8] , prflbrsec_tbl[1..rowsof(prflbrsec_tbl),3..4] , prflbrsec_tbl[1..rowsof(prflbrsec_tbl),1..2]
est2tex prflbrsec, replace dropall preserve ready path(brazempl/tex/heckman/tables) fancy extracols(2 4 6)
local rows = rowsof(prflcomp_tbl)
* mat prflcomp_tbl = prflcomp_tbl[1..`rows',1] , prflcomp_tbl[1..`rows',3..4]
est2tex prflcomp, replace dropall preserve ready path(brazempl/tex/heckman/tables) fancy 

* Comparison of premia with and without selection correction
matload prflbrsec_tbl, p(brazempl/tex/v1/tables) over dropall
mat prflselcomp_tbl = prflcomp_tbl[1..`rows',1] , prflbrsec_tbl[1..`rows',1] , prflcomp_tbl[1..`rows',2] , prflbrsec_tbl[1..`rows',2]
matname prflselcomp_tbl br90sec4sel br90sec4nosel br97sec4sel br97sec4nosel, columns(1..4) explicit
est2tex prflselcomp, replace dropall preserve ready path(brazempl/tex/heckman/tables) fancy extracols(2)

cd "$home"
