version 8
clear
set matsize 180
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture mkdir "brazempl/tex/nonparam/tables"

/* Load variable names and save for est2tex */

insheet using "brazempl/tex/regressor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "brazempl/tex/nonparam/tables/prflselcomp_rowlbl", replace
clear


/* Load Profile Matrices */

foreach profile in edu occu sex {
 foreach type in comp brsec {
  matload prfl`type'`profile'_tbl, p(brazempl/tex/nonparam) over dropall
  * matload prfl`type'plain`profile'_tbl, p(brazempl/tex/nonparam/tables) over dropall
  }
 }


/* Profile Tables for education, occupation, gender: Brazil 1990 and 1997 */

* Wage profile tables
foreach type in comp brsec {
  local cols = colsof(prfl`type'edu_tbl)
  local colnames : colfullnames prfl`type'edu_tbl
  mat prfl`type'_tbl = J(1,`cols',1) \ prfl`type'edu_tbl[1..3,1..`cols'] \ J(1,`cols',1) \ prfl`type'edu_tbl[4..6,1..`cols'] \ prfl`type'occu_tbl[1..4,1..`cols'] \ J(1,`cols',1) \ prfl`type'occu_tbl[5..8,1..`cols'] \ J(1,`cols',1) \ prfl`type'sex_tbl[1..2,1..`cols']
  matname prfl`type'_tbl grad:masc, rows(1) explicit
  matname prfl`type'_tbl grad:fem, rows(5) explicit 
  matname prfl`type'_tbl unskl:masc, rows(13) explicit
  matname prfl`type'_tbl unskl:fem, rows(18) explicit
  matname prfl`type'_tbl `colnames', columns(1..`cols') explicit
  forvalues col = 1/`cols' {
   foreach row in 1 2 4 {
     mat prfl`type'_tbl[`row',`col'] = prfl`type'_tbl[`row',`col'] / prfl`type'_tbl[3,`col']
     }
   mat prfl`type'_tbl[3,`col'] = prfl`type'_tbl[3,`col'] / prfl`type'_tbl[3,`col']
   foreach row in 5 6 8 {
     mat prfl`type'_tbl[`row',`col'] = prfl`type'_tbl[`row',`col'] / prfl`type'_tbl[7,`col']
     }
   mat prfl`type'_tbl[7,`col'] = prfl`type'_tbl[7,`col'] / prfl`type'_tbl[7,`col']
   }
  }
mat prflbrsec_tbl = prflbrsec_tbl[1..rowsof(prflbrsec_tbl),5..8] , prflbrsec_tbl[1..rowsof(prflbrsec_tbl),3..4] , prflbrsec_tbl[1..rowsof(prflbrsec_tbl),1..2]
est2tex prflbrsec, replace dropall preserve ready path(brazempl/tex/nonparam/tables) fancy extracols(2 4 6)
local rows = rowsof(prflcomp_tbl)
* mat prflcomp_tbl = prflcomp_tbl[1..`rows',1] , prflcomp_tbl[1..`rows',3..4]
est2tex prflcomp, replace dropall preserve ready path(brazempl/tex/nonparam/tables) fancy 

* Comparison of premia with and without selection correction
matload prflselcomp_tbl, p(brazempl/tex/heckman/tables) over dropall
mat prflselcomp_tbl = prflselcomp_tbl[1..`rows',2] , prflselcomp_tbl[1..`rows',1] , prflcomp_tbl[1..`rows',1] , prflselcomp_tbl[1..`rows',4] , prflselcomp_tbl[1..`rows',3] , prflcomp_tbl[1..`rows',2]
matname prflselcomp_tbl br90sec4nosel br90sec4selhm br90sec4selnp br97sec4nosel br97sec4selhm br97sec4selnp, columns(1..6) explicit
est2tex prflselcomp, replace dropall preserve ready path(brazempl/tex/nonparam/tables) fancy extracols(3)

cd "$home"
