*! version 2.6.9  05aug2002

/*  Note:  Heck2 assumes that the regression w/ a Mills ratio is the
 *  current set of estimates */

program define Heck2, eclass   /* BetaReg rho sigma Cov(probit) 
                  RegVars RecCons PrbVars Mills touse */
    args        b       /*  regression Beta
        */  rho     /*  
        */  sigma   /*
        */  bprb    /*  probit Beta
        */  Vprb    /*  probit VCE
        */  dep     /*  dependent variable
        */  ind     /*  independent varlist
        */  nc      /*  "" or "noconstant"
        */  seldep  /*  selection eqn dependent variable
        */  selind  /*  selection eqn indep varlist
        */  selnc   /*  selection eqn : "" or "noconstant"
        */  mills   /*  Mills' ratio
        */  delthat /*
        */  touse   /*  To use variable
        */  rhometh /*  method of using rho
        */  rho1    /*  original two-step rho if outide -1,1 */

    tempname XpX1 F Q rho2 VBm 

    /* Compute Heckman's two-step consistent estimates of Cov */

                    /* Get X'X inverse from the 
                     * second-step regression */

    if e(rmse) != 0 {
      matrix `XpX1' = get(VCE) / e(rmse)^2
      if "`e(cmd)'"=="xtreg" {  /* Exchange estimate on `one' for _cons */
        tempname colsxt xtXpX1 colcnst colmils
        local comprow : rownames `XpX1'
        local colsxt = colsof(`XpX1')
        tokenize `comprow'
        matrix `xtXpX1' = `XpX1'[1..`colsxt'-3,1..`colsxt'-3]
        matrix `colcnst' = `XpX1'[`colsxt',1..`colsxt'] '
        matrix `colcnst'[`colsxt'-2,1] = `colcnst'[`colsxt',1]
        matrix `colmils' = `XpX1'[`colsxt'-1,1..`colsxt'] '
        matrix `colmils'[`colsxt'-2,1] = `colmils'[`colsxt',1]
        matrix `XpX1' = ( `xtXpX1' , `colcnst'[1..`colsxt'-3,1]) \ `colcnst'[1..`colsxt'-2,1] '
        matrix `XpX1' = (  `XpX1'  , `colmils'[1..`colsxt'-2,1]) \ `colmils'[1..`colsxt'-1,1] '
        local oldcons = `colsxt'-2
        matname `XpX1' ``oldcons'', rows(`oldcons') explicit
        matname `XpX1' ``oldcons'', columns(`oldcons') explicit
        }     
    }
    else {
di in red "insufficient information in sample to estimate heckman model"
        exit 2000
    }

                    /*  Heckman's adjustment to Cov  */
    local fulnam `ind'
    if "`nc'" == "" {
        tempvar one
        g byte `one' = 1
        local fulnam "`fulnam' _cons"
    }
    local fulnam "`fulnam' lambda"
    local kreg : word count `fulnam'
    local kreg1 = `kreg' + 1
    qui mat accum `F' = `ind' `one' `mills' `selind' [iw=`delthat'], /*
        */ `selnc', if `touse' & `seldep'
    mat `F' = `F'[1..`kreg', `kreg1'...]
    mat rowname `F' = `fulnam'
    scalar `rho2' = `rho' * `rho'
    mat `Q' = `rho2' * `F'*`Vprb'*`F''

                    /* Finish the variance computation */
    tempvar rho2del
    if (`rho' < -1 | `rho' > 1) & `rhometh' == 3 { scalar `rho2' = 1 }
    qui gen double `rho2del' = 1 - `rho2' * `delthat'  if `touse'
    qui mat accum `VBm' = `ind' `one' `mills' [iw=`rho2del'], /*
        */ nocons,  if `touse' & `seldep'
    mat `VBm' = `sigma'^2 * `XpX1' * (`VBm' + `Q') * `XpX1'

                    /* Build the set of full eqn names */
    local eqnam
    tokenize `fulnam'
    local i 1
    while `i' < `kreg' {
        local eqnam `eqnam' `dep':``i''
        local i = `i' + 1
    }

    if substr("`seldep'",1,2) != "__" {
        local selname `seldep'
    }
    else    local selname select
    local kprb : word count `selind'
    local i 1
    tokenize `selind'
    while `i' <= `kprb' {
        local eqnam `eqnam' `selname':``i''
        local i = `i' + 1
    }
    if "`selnc'" == "" { 
        local eqnam `eqnam' `selname':_cons 
        local kprb = `kprb' + 1
    }
    local eqnam `eqnam' mills:lambda

                    /*  Put model and selection 
                     *  equation together 
                     *  Quicker w/ matrix expr, but would
                     *  be hard to understand */

    tempname bfull Vfull zeros Vmills CovMill zeroPrb b0 bmills
    local kreg0 = `kreg' - 1
    mat `b0' = `b'[1,1..`kreg0'] 
    mat `bmills' = `b'[1,`kreg'] 
    mat `bfull' = `b0', `bprb' , `bmills'
    mat `Vmills' = `VBm'[`kreg', `kreg']
    mat `CovMill' = `VBm'[1..`kreg0', `kreg']
    mat `VBm' = `VBm'[1..`kreg0', 1..`kreg0']
    mat `zeros' = J(`kreg0', `kprb', 0)
    mat `zeroPrb' = J(`kprb', 1, 0)
    mat `VBm' = /*
        */  ( `VBm'       , `zeros'    ,  `CovMills' \      /*
        */    `zeros''    , `Vprb'     ,  `zeroPrb'  \      /*
        */    `CovMills'' , `zeroPrb'' ,  `Vmills' )
    mat `VBm' = (`VBm' + `VBm'') / 2
    mat colnames `bfull' = `eqnam'
    mat rownames `VBm' = `eqnam'
    mat colnames `VBm' = `eqnam'

    qui count if `touse'
    capture est post `bfull' `VBm', obs(`r(N)')
    if _rc {
        if _rc == 506 {
            di in red "estimate of rho outside the interval "  /*
                */ "[-1, 1] has led to a covariance matrix"
            di in red "that is not positive definite"
            * mat `VBm' = 0*`VBm'
            mat `VBm'[1, 1] = 0*`VBm'[1..`kreg0', 1..`kreg0']
        }
        est post `bfull' `VBm', obs(`r(N)')
    }

    est scalar N = `r(N)'
    capture qui test `ind', min
    if _rc == 0 {
        est scalar chi2 = `r(chi2)'
        est scalar df_m = `r(df)'
        est scalar p    = `r(p)'
    }
    qui count if `seldep' == 0 & `touse'
    est scalar N_cens = r(N)    /* early, sic */
    est local chi2type "Wald"
    est local title2 "(regression model with sample selection)"
    est local title "Heckman selection model -- two-step estimates"
    if substr("`mills'", 1, 2) != "__" { est local mills `mills' }
    est scalar rho = `rho'
    if `rho1' != `rho' { est scalar rho1 = `rho1' }
    est scalar sigma = `sigma'
    est scalar lambda = [mills]_b[lambda]
    est scalar selambda = [mills]_se[lambda]
    est local predict "heckma_p"
end
