*! version 1.0.2  28oct2006  by Marc Muendler  muendler@ucsd.edu

program hokleinspady_lf, sortpreserve
    version 8.2
    args lnf xb
    tempvar obssrt hnlambda z fh rh kh khy Gn

    * to active alternative kernels, see remarks below on: Gaussian, Martins (JApplEmetrics 16 2001, 23-39), Horowitz (JEmetrics 58 1993, 49-70)

    // no trimming

    quietly {
      // summ data, set bandwidth
      summ `xb' if $ML_samp
      local np = r(N)
      local sy = r(sd)
      gen `obssrt' = _n if $ML_samp
      sort `xb' `obssrt'
      local hnp = `np'^(-1/6.02)  // non-stochastic component as in Klein and Spady (1993) Monte-Carlo simulations
      gen double `hnlambda' = `hnp'  // fixed bandwidth, no adaptive smoothing

      // leave-one-out Nadaraya-Watson kernel as in Haerdle, Mueller, Sperlich and Werwatz (2004, ch. 6.2.2)
      gen double `z'  = 0 if $ML_samp
      gen double `fh' = 0 if $ML_samp
      gen double `rh' = 0 if $ML_samp
      gen double `kh' = 0 if $ML_samp
      gen double `khy' = 0 if $ML_samp
      local i = 1
      while `i' <= `np' {
        local xo = `xb'[`i']
        replace `z' = (`xo' - `xb') / `hnlambda' if $ML_samp
        * replace `kh' = (1/(sqrt(2*_pi)))*exp(-.5*`z'*`z')  // Gaussian
        replace `kh' = (1/(sqrt(2*_pi)))*exp(-`z'*`z'/2)*(3/2-`z'*`z'/2)  // Martins (JApplEmetrics 16 2001, 23-39)
        * replace `kh' = (21/64)*(1-5*(`z'/5)*(`z'/5)+7*(`z'/5)*(`z'/5)*(`z'/5)*(`z'/5)-3*(`z'/5)*(`z'/5)*(`z'/5)*(`z'/5)*(`z'/5)*(`z'/5))  if abs(`z') < 5  // Horowitz (JEmetrics 58 1993, 49-70)
        replace `khy' = $ML_y1*`kh'
        summ `kh' if `obssrt'!=`i', meanonly   // leave-one-out implementation
        replace `fh' = `r(sum)' in `i'
        summ `khy' if `obssrt'!=`i', meanonly  // leave-one-out implementation
        replace `rh' = `r(sum)' in `i'
        replace `kh'  = 0 if $ML_samp
        replace `khy' = 0 if $ML_samp
        local i = `i' + 1
        }

      * gen double `Gn' = normal(`xb')  // for probit replication
      gen double `Gn' = `rh'/`fh' if _n <= `np'

      replace `lnf' = .5 * [ $ML_y1 * ln(`Gn'*`Gn') + (1-$ML_y1) * ln((1-`Gn')*(1-`Gn')) ]   // squares to avoid numerical problems, cf. Haerdle et al. (2004, ch. 6.2.2)
      }
end 
